# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAccountResult',
    'AwaitableGetAccountResult',
    'get_account',
    'get_account_output',
]

@pulumi.output_type
class GetAccountResult:
    """
    A collection of values returned by getAccount.
    """
    def __init__(__self__, access_tier=None, account_kind=None, account_replication_type=None, account_tier=None, allow_nested_items_to_be_public=None, azure_files_authentications=None, custom_domains=None, dns_endpoint_type=None, https_traffic_only_enabled=None, id=None, identities=None, infrastructure_encryption_enabled=None, is_hns_enabled=None, location=None, min_tls_version=None, name=None, nfsv3_enabled=None, primary_access_key=None, primary_blob_connection_string=None, primary_blob_endpoint=None, primary_blob_host=None, primary_blob_internet_endpoint=None, primary_blob_internet_host=None, primary_blob_microsoft_endpoint=None, primary_blob_microsoft_host=None, primary_connection_string=None, primary_dfs_endpoint=None, primary_dfs_host=None, primary_dfs_internet_endpoint=None, primary_dfs_internet_host=None, primary_dfs_microsoft_endpoint=None, primary_dfs_microsoft_host=None, primary_file_endpoint=None, primary_file_host=None, primary_file_internet_endpoint=None, primary_file_internet_host=None, primary_file_microsoft_endpoint=None, primary_file_microsoft_host=None, primary_location=None, primary_queue_endpoint=None, primary_queue_host=None, primary_queue_microsoft_endpoint=None, primary_queue_microsoft_host=None, primary_table_endpoint=None, primary_table_host=None, primary_table_microsoft_endpoint=None, primary_table_microsoft_host=None, primary_web_endpoint=None, primary_web_host=None, primary_web_internet_endpoint=None, primary_web_internet_host=None, primary_web_microsoft_endpoint=None, primary_web_microsoft_host=None, queue_encryption_key_type=None, resource_group_name=None, secondary_access_key=None, secondary_blob_connection_string=None, secondary_blob_endpoint=None, secondary_blob_host=None, secondary_blob_internet_endpoint=None, secondary_blob_internet_host=None, secondary_blob_microsoft_endpoint=None, secondary_blob_microsoft_host=None, secondary_connection_string=None, secondary_dfs_endpoint=None, secondary_dfs_host=None, secondary_dfs_internet_endpoint=None, secondary_dfs_internet_host=None, secondary_dfs_microsoft_endpoint=None, secondary_dfs_microsoft_host=None, secondary_file_endpoint=None, secondary_file_host=None, secondary_file_internet_endpoint=None, secondary_file_internet_host=None, secondary_file_microsoft_endpoint=None, secondary_file_microsoft_host=None, secondary_location=None, secondary_queue_endpoint=None, secondary_queue_host=None, secondary_queue_microsoft_endpoint=None, secondary_queue_microsoft_host=None, secondary_table_endpoint=None, secondary_table_host=None, secondary_table_microsoft_endpoint=None, secondary_table_microsoft_host=None, secondary_web_endpoint=None, secondary_web_host=None, secondary_web_internet_endpoint=None, secondary_web_internet_host=None, secondary_web_microsoft_endpoint=None, secondary_web_microsoft_host=None, table_encryption_key_type=None, tags=None):
        if access_tier and not isinstance(access_tier, str):
            raise TypeError("Expected argument 'access_tier' to be a str")
        pulumi.set(__self__, "access_tier", access_tier)
        if account_kind and not isinstance(account_kind, str):
            raise TypeError("Expected argument 'account_kind' to be a str")
        pulumi.set(__self__, "account_kind", account_kind)
        if account_replication_type and not isinstance(account_replication_type, str):
            raise TypeError("Expected argument 'account_replication_type' to be a str")
        pulumi.set(__self__, "account_replication_type", account_replication_type)
        if account_tier and not isinstance(account_tier, str):
            raise TypeError("Expected argument 'account_tier' to be a str")
        pulumi.set(__self__, "account_tier", account_tier)
        if allow_nested_items_to_be_public and not isinstance(allow_nested_items_to_be_public, bool):
            raise TypeError("Expected argument 'allow_nested_items_to_be_public' to be a bool")
        pulumi.set(__self__, "allow_nested_items_to_be_public", allow_nested_items_to_be_public)
        if azure_files_authentications and not isinstance(azure_files_authentications, list):
            raise TypeError("Expected argument 'azure_files_authentications' to be a list")
        pulumi.set(__self__, "azure_files_authentications", azure_files_authentications)
        if custom_domains and not isinstance(custom_domains, list):
            raise TypeError("Expected argument 'custom_domains' to be a list")
        pulumi.set(__self__, "custom_domains", custom_domains)
        if dns_endpoint_type and not isinstance(dns_endpoint_type, str):
            raise TypeError("Expected argument 'dns_endpoint_type' to be a str")
        pulumi.set(__self__, "dns_endpoint_type", dns_endpoint_type)
        if https_traffic_only_enabled and not isinstance(https_traffic_only_enabled, bool):
            raise TypeError("Expected argument 'https_traffic_only_enabled' to be a bool")
        pulumi.set(__self__, "https_traffic_only_enabled", https_traffic_only_enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identities and not isinstance(identities, list):
            raise TypeError("Expected argument 'identities' to be a list")
        pulumi.set(__self__, "identities", identities)
        if infrastructure_encryption_enabled and not isinstance(infrastructure_encryption_enabled, bool):
            raise TypeError("Expected argument 'infrastructure_encryption_enabled' to be a bool")
        pulumi.set(__self__, "infrastructure_encryption_enabled", infrastructure_encryption_enabled)
        if is_hns_enabled and not isinstance(is_hns_enabled, bool):
            raise TypeError("Expected argument 'is_hns_enabled' to be a bool")
        pulumi.set(__self__, "is_hns_enabled", is_hns_enabled)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if min_tls_version and not isinstance(min_tls_version, str):
            raise TypeError("Expected argument 'min_tls_version' to be a str")
        pulumi.set(__self__, "min_tls_version", min_tls_version)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if nfsv3_enabled and not isinstance(nfsv3_enabled, bool):
            raise TypeError("Expected argument 'nfsv3_enabled' to be a bool")
        pulumi.set(__self__, "nfsv3_enabled", nfsv3_enabled)
        if primary_access_key and not isinstance(primary_access_key, str):
            raise TypeError("Expected argument 'primary_access_key' to be a str")
        pulumi.set(__self__, "primary_access_key", primary_access_key)
        if primary_blob_connection_string and not isinstance(primary_blob_connection_string, str):
            raise TypeError("Expected argument 'primary_blob_connection_string' to be a str")
        pulumi.set(__self__, "primary_blob_connection_string", primary_blob_connection_string)
        if primary_blob_endpoint and not isinstance(primary_blob_endpoint, str):
            raise TypeError("Expected argument 'primary_blob_endpoint' to be a str")
        pulumi.set(__self__, "primary_blob_endpoint", primary_blob_endpoint)
        if primary_blob_host and not isinstance(primary_blob_host, str):
            raise TypeError("Expected argument 'primary_blob_host' to be a str")
        pulumi.set(__self__, "primary_blob_host", primary_blob_host)
        if primary_blob_internet_endpoint and not isinstance(primary_blob_internet_endpoint, str):
            raise TypeError("Expected argument 'primary_blob_internet_endpoint' to be a str")
        pulumi.set(__self__, "primary_blob_internet_endpoint", primary_blob_internet_endpoint)
        if primary_blob_internet_host and not isinstance(primary_blob_internet_host, str):
            raise TypeError("Expected argument 'primary_blob_internet_host' to be a str")
        pulumi.set(__self__, "primary_blob_internet_host", primary_blob_internet_host)
        if primary_blob_microsoft_endpoint and not isinstance(primary_blob_microsoft_endpoint, str):
            raise TypeError("Expected argument 'primary_blob_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "primary_blob_microsoft_endpoint", primary_blob_microsoft_endpoint)
        if primary_blob_microsoft_host and not isinstance(primary_blob_microsoft_host, str):
            raise TypeError("Expected argument 'primary_blob_microsoft_host' to be a str")
        pulumi.set(__self__, "primary_blob_microsoft_host", primary_blob_microsoft_host)
        if primary_connection_string and not isinstance(primary_connection_string, str):
            raise TypeError("Expected argument 'primary_connection_string' to be a str")
        pulumi.set(__self__, "primary_connection_string", primary_connection_string)
        if primary_dfs_endpoint and not isinstance(primary_dfs_endpoint, str):
            raise TypeError("Expected argument 'primary_dfs_endpoint' to be a str")
        pulumi.set(__self__, "primary_dfs_endpoint", primary_dfs_endpoint)
        if primary_dfs_host and not isinstance(primary_dfs_host, str):
            raise TypeError("Expected argument 'primary_dfs_host' to be a str")
        pulumi.set(__self__, "primary_dfs_host", primary_dfs_host)
        if primary_dfs_internet_endpoint and not isinstance(primary_dfs_internet_endpoint, str):
            raise TypeError("Expected argument 'primary_dfs_internet_endpoint' to be a str")
        pulumi.set(__self__, "primary_dfs_internet_endpoint", primary_dfs_internet_endpoint)
        if primary_dfs_internet_host and not isinstance(primary_dfs_internet_host, str):
            raise TypeError("Expected argument 'primary_dfs_internet_host' to be a str")
        pulumi.set(__self__, "primary_dfs_internet_host", primary_dfs_internet_host)
        if primary_dfs_microsoft_endpoint and not isinstance(primary_dfs_microsoft_endpoint, str):
            raise TypeError("Expected argument 'primary_dfs_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "primary_dfs_microsoft_endpoint", primary_dfs_microsoft_endpoint)
        if primary_dfs_microsoft_host and not isinstance(primary_dfs_microsoft_host, str):
            raise TypeError("Expected argument 'primary_dfs_microsoft_host' to be a str")
        pulumi.set(__self__, "primary_dfs_microsoft_host", primary_dfs_microsoft_host)
        if primary_file_endpoint and not isinstance(primary_file_endpoint, str):
            raise TypeError("Expected argument 'primary_file_endpoint' to be a str")
        pulumi.set(__self__, "primary_file_endpoint", primary_file_endpoint)
        if primary_file_host and not isinstance(primary_file_host, str):
            raise TypeError("Expected argument 'primary_file_host' to be a str")
        pulumi.set(__self__, "primary_file_host", primary_file_host)
        if primary_file_internet_endpoint and not isinstance(primary_file_internet_endpoint, str):
            raise TypeError("Expected argument 'primary_file_internet_endpoint' to be a str")
        pulumi.set(__self__, "primary_file_internet_endpoint", primary_file_internet_endpoint)
        if primary_file_internet_host and not isinstance(primary_file_internet_host, str):
            raise TypeError("Expected argument 'primary_file_internet_host' to be a str")
        pulumi.set(__self__, "primary_file_internet_host", primary_file_internet_host)
        if primary_file_microsoft_endpoint and not isinstance(primary_file_microsoft_endpoint, str):
            raise TypeError("Expected argument 'primary_file_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "primary_file_microsoft_endpoint", primary_file_microsoft_endpoint)
        if primary_file_microsoft_host and not isinstance(primary_file_microsoft_host, str):
            raise TypeError("Expected argument 'primary_file_microsoft_host' to be a str")
        pulumi.set(__self__, "primary_file_microsoft_host", primary_file_microsoft_host)
        if primary_location and not isinstance(primary_location, str):
            raise TypeError("Expected argument 'primary_location' to be a str")
        pulumi.set(__self__, "primary_location", primary_location)
        if primary_queue_endpoint and not isinstance(primary_queue_endpoint, str):
            raise TypeError("Expected argument 'primary_queue_endpoint' to be a str")
        pulumi.set(__self__, "primary_queue_endpoint", primary_queue_endpoint)
        if primary_queue_host and not isinstance(primary_queue_host, str):
            raise TypeError("Expected argument 'primary_queue_host' to be a str")
        pulumi.set(__self__, "primary_queue_host", primary_queue_host)
        if primary_queue_microsoft_endpoint and not isinstance(primary_queue_microsoft_endpoint, str):
            raise TypeError("Expected argument 'primary_queue_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "primary_queue_microsoft_endpoint", primary_queue_microsoft_endpoint)
        if primary_queue_microsoft_host and not isinstance(primary_queue_microsoft_host, str):
            raise TypeError("Expected argument 'primary_queue_microsoft_host' to be a str")
        pulumi.set(__self__, "primary_queue_microsoft_host", primary_queue_microsoft_host)
        if primary_table_endpoint and not isinstance(primary_table_endpoint, str):
            raise TypeError("Expected argument 'primary_table_endpoint' to be a str")
        pulumi.set(__self__, "primary_table_endpoint", primary_table_endpoint)
        if primary_table_host and not isinstance(primary_table_host, str):
            raise TypeError("Expected argument 'primary_table_host' to be a str")
        pulumi.set(__self__, "primary_table_host", primary_table_host)
        if primary_table_microsoft_endpoint and not isinstance(primary_table_microsoft_endpoint, str):
            raise TypeError("Expected argument 'primary_table_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "primary_table_microsoft_endpoint", primary_table_microsoft_endpoint)
        if primary_table_microsoft_host and not isinstance(primary_table_microsoft_host, str):
            raise TypeError("Expected argument 'primary_table_microsoft_host' to be a str")
        pulumi.set(__self__, "primary_table_microsoft_host", primary_table_microsoft_host)
        if primary_web_endpoint and not isinstance(primary_web_endpoint, str):
            raise TypeError("Expected argument 'primary_web_endpoint' to be a str")
        pulumi.set(__self__, "primary_web_endpoint", primary_web_endpoint)
        if primary_web_host and not isinstance(primary_web_host, str):
            raise TypeError("Expected argument 'primary_web_host' to be a str")
        pulumi.set(__self__, "primary_web_host", primary_web_host)
        if primary_web_internet_endpoint and not isinstance(primary_web_internet_endpoint, str):
            raise TypeError("Expected argument 'primary_web_internet_endpoint' to be a str")
        pulumi.set(__self__, "primary_web_internet_endpoint", primary_web_internet_endpoint)
        if primary_web_internet_host and not isinstance(primary_web_internet_host, str):
            raise TypeError("Expected argument 'primary_web_internet_host' to be a str")
        pulumi.set(__self__, "primary_web_internet_host", primary_web_internet_host)
        if primary_web_microsoft_endpoint and not isinstance(primary_web_microsoft_endpoint, str):
            raise TypeError("Expected argument 'primary_web_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "primary_web_microsoft_endpoint", primary_web_microsoft_endpoint)
        if primary_web_microsoft_host and not isinstance(primary_web_microsoft_host, str):
            raise TypeError("Expected argument 'primary_web_microsoft_host' to be a str")
        pulumi.set(__self__, "primary_web_microsoft_host", primary_web_microsoft_host)
        if queue_encryption_key_type and not isinstance(queue_encryption_key_type, str):
            raise TypeError("Expected argument 'queue_encryption_key_type' to be a str")
        pulumi.set(__self__, "queue_encryption_key_type", queue_encryption_key_type)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if secondary_access_key and not isinstance(secondary_access_key, str):
            raise TypeError("Expected argument 'secondary_access_key' to be a str")
        pulumi.set(__self__, "secondary_access_key", secondary_access_key)
        if secondary_blob_connection_string and not isinstance(secondary_blob_connection_string, str):
            raise TypeError("Expected argument 'secondary_blob_connection_string' to be a str")
        pulumi.set(__self__, "secondary_blob_connection_string", secondary_blob_connection_string)
        if secondary_blob_endpoint and not isinstance(secondary_blob_endpoint, str):
            raise TypeError("Expected argument 'secondary_blob_endpoint' to be a str")
        pulumi.set(__self__, "secondary_blob_endpoint", secondary_blob_endpoint)
        if secondary_blob_host and not isinstance(secondary_blob_host, str):
            raise TypeError("Expected argument 'secondary_blob_host' to be a str")
        pulumi.set(__self__, "secondary_blob_host", secondary_blob_host)
        if secondary_blob_internet_endpoint and not isinstance(secondary_blob_internet_endpoint, str):
            raise TypeError("Expected argument 'secondary_blob_internet_endpoint' to be a str")
        pulumi.set(__self__, "secondary_blob_internet_endpoint", secondary_blob_internet_endpoint)
        if secondary_blob_internet_host and not isinstance(secondary_blob_internet_host, str):
            raise TypeError("Expected argument 'secondary_blob_internet_host' to be a str")
        pulumi.set(__self__, "secondary_blob_internet_host", secondary_blob_internet_host)
        if secondary_blob_microsoft_endpoint and not isinstance(secondary_blob_microsoft_endpoint, str):
            raise TypeError("Expected argument 'secondary_blob_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "secondary_blob_microsoft_endpoint", secondary_blob_microsoft_endpoint)
        if secondary_blob_microsoft_host and not isinstance(secondary_blob_microsoft_host, str):
            raise TypeError("Expected argument 'secondary_blob_microsoft_host' to be a str")
        pulumi.set(__self__, "secondary_blob_microsoft_host", secondary_blob_microsoft_host)
        if secondary_connection_string and not isinstance(secondary_connection_string, str):
            raise TypeError("Expected argument 'secondary_connection_string' to be a str")
        pulumi.set(__self__, "secondary_connection_string", secondary_connection_string)
        if secondary_dfs_endpoint and not isinstance(secondary_dfs_endpoint, str):
            raise TypeError("Expected argument 'secondary_dfs_endpoint' to be a str")
        pulumi.set(__self__, "secondary_dfs_endpoint", secondary_dfs_endpoint)
        if secondary_dfs_host and not isinstance(secondary_dfs_host, str):
            raise TypeError("Expected argument 'secondary_dfs_host' to be a str")
        pulumi.set(__self__, "secondary_dfs_host", secondary_dfs_host)
        if secondary_dfs_internet_endpoint and not isinstance(secondary_dfs_internet_endpoint, str):
            raise TypeError("Expected argument 'secondary_dfs_internet_endpoint' to be a str")
        pulumi.set(__self__, "secondary_dfs_internet_endpoint", secondary_dfs_internet_endpoint)
        if secondary_dfs_internet_host and not isinstance(secondary_dfs_internet_host, str):
            raise TypeError("Expected argument 'secondary_dfs_internet_host' to be a str")
        pulumi.set(__self__, "secondary_dfs_internet_host", secondary_dfs_internet_host)
        if secondary_dfs_microsoft_endpoint and not isinstance(secondary_dfs_microsoft_endpoint, str):
            raise TypeError("Expected argument 'secondary_dfs_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "secondary_dfs_microsoft_endpoint", secondary_dfs_microsoft_endpoint)
        if secondary_dfs_microsoft_host and not isinstance(secondary_dfs_microsoft_host, str):
            raise TypeError("Expected argument 'secondary_dfs_microsoft_host' to be a str")
        pulumi.set(__self__, "secondary_dfs_microsoft_host", secondary_dfs_microsoft_host)
        if secondary_file_endpoint and not isinstance(secondary_file_endpoint, str):
            raise TypeError("Expected argument 'secondary_file_endpoint' to be a str")
        pulumi.set(__self__, "secondary_file_endpoint", secondary_file_endpoint)
        if secondary_file_host and not isinstance(secondary_file_host, str):
            raise TypeError("Expected argument 'secondary_file_host' to be a str")
        pulumi.set(__self__, "secondary_file_host", secondary_file_host)
        if secondary_file_internet_endpoint and not isinstance(secondary_file_internet_endpoint, str):
            raise TypeError("Expected argument 'secondary_file_internet_endpoint' to be a str")
        pulumi.set(__self__, "secondary_file_internet_endpoint", secondary_file_internet_endpoint)
        if secondary_file_internet_host and not isinstance(secondary_file_internet_host, str):
            raise TypeError("Expected argument 'secondary_file_internet_host' to be a str")
        pulumi.set(__self__, "secondary_file_internet_host", secondary_file_internet_host)
        if secondary_file_microsoft_endpoint and not isinstance(secondary_file_microsoft_endpoint, str):
            raise TypeError("Expected argument 'secondary_file_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "secondary_file_microsoft_endpoint", secondary_file_microsoft_endpoint)
        if secondary_file_microsoft_host and not isinstance(secondary_file_microsoft_host, str):
            raise TypeError("Expected argument 'secondary_file_microsoft_host' to be a str")
        pulumi.set(__self__, "secondary_file_microsoft_host", secondary_file_microsoft_host)
        if secondary_location and not isinstance(secondary_location, str):
            raise TypeError("Expected argument 'secondary_location' to be a str")
        pulumi.set(__self__, "secondary_location", secondary_location)
        if secondary_queue_endpoint and not isinstance(secondary_queue_endpoint, str):
            raise TypeError("Expected argument 'secondary_queue_endpoint' to be a str")
        pulumi.set(__self__, "secondary_queue_endpoint", secondary_queue_endpoint)
        if secondary_queue_host and not isinstance(secondary_queue_host, str):
            raise TypeError("Expected argument 'secondary_queue_host' to be a str")
        pulumi.set(__self__, "secondary_queue_host", secondary_queue_host)
        if secondary_queue_microsoft_endpoint and not isinstance(secondary_queue_microsoft_endpoint, str):
            raise TypeError("Expected argument 'secondary_queue_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "secondary_queue_microsoft_endpoint", secondary_queue_microsoft_endpoint)
        if secondary_queue_microsoft_host and not isinstance(secondary_queue_microsoft_host, str):
            raise TypeError("Expected argument 'secondary_queue_microsoft_host' to be a str")
        pulumi.set(__self__, "secondary_queue_microsoft_host", secondary_queue_microsoft_host)
        if secondary_table_endpoint and not isinstance(secondary_table_endpoint, str):
            raise TypeError("Expected argument 'secondary_table_endpoint' to be a str")
        pulumi.set(__self__, "secondary_table_endpoint", secondary_table_endpoint)
        if secondary_table_host and not isinstance(secondary_table_host, str):
            raise TypeError("Expected argument 'secondary_table_host' to be a str")
        pulumi.set(__self__, "secondary_table_host", secondary_table_host)
        if secondary_table_microsoft_endpoint and not isinstance(secondary_table_microsoft_endpoint, str):
            raise TypeError("Expected argument 'secondary_table_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "secondary_table_microsoft_endpoint", secondary_table_microsoft_endpoint)
        if secondary_table_microsoft_host and not isinstance(secondary_table_microsoft_host, str):
            raise TypeError("Expected argument 'secondary_table_microsoft_host' to be a str")
        pulumi.set(__self__, "secondary_table_microsoft_host", secondary_table_microsoft_host)
        if secondary_web_endpoint and not isinstance(secondary_web_endpoint, str):
            raise TypeError("Expected argument 'secondary_web_endpoint' to be a str")
        pulumi.set(__self__, "secondary_web_endpoint", secondary_web_endpoint)
        if secondary_web_host and not isinstance(secondary_web_host, str):
            raise TypeError("Expected argument 'secondary_web_host' to be a str")
        pulumi.set(__self__, "secondary_web_host", secondary_web_host)
        if secondary_web_internet_endpoint and not isinstance(secondary_web_internet_endpoint, str):
            raise TypeError("Expected argument 'secondary_web_internet_endpoint' to be a str")
        pulumi.set(__self__, "secondary_web_internet_endpoint", secondary_web_internet_endpoint)
        if secondary_web_internet_host and not isinstance(secondary_web_internet_host, str):
            raise TypeError("Expected argument 'secondary_web_internet_host' to be a str")
        pulumi.set(__self__, "secondary_web_internet_host", secondary_web_internet_host)
        if secondary_web_microsoft_endpoint and not isinstance(secondary_web_microsoft_endpoint, str):
            raise TypeError("Expected argument 'secondary_web_microsoft_endpoint' to be a str")
        pulumi.set(__self__, "secondary_web_microsoft_endpoint", secondary_web_microsoft_endpoint)
        if secondary_web_microsoft_host and not isinstance(secondary_web_microsoft_host, str):
            raise TypeError("Expected argument 'secondary_web_microsoft_host' to be a str")
        pulumi.set(__self__, "secondary_web_microsoft_host", secondary_web_microsoft_host)
        if table_encryption_key_type and not isinstance(table_encryption_key_type, str):
            raise TypeError("Expected argument 'table_encryption_key_type' to be a str")
        pulumi.set(__self__, "table_encryption_key_type", table_encryption_key_type)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="accessTier")
    def access_tier(self) -> str:
        """
        The access tier for `BlobStorage` accounts.
        """
        return pulumi.get(self, "access_tier")

    @property
    @pulumi.getter(name="accountKind")
    def account_kind(self) -> str:
        """
        The Kind of account.
        """
        return pulumi.get(self, "account_kind")

    @property
    @pulumi.getter(name="accountReplicationType")
    def account_replication_type(self) -> str:
        """
        The type of replication used for this storage account.
        """
        return pulumi.get(self, "account_replication_type")

    @property
    @pulumi.getter(name="accountTier")
    def account_tier(self) -> str:
        """
        The Tier of this storage account.
        """
        return pulumi.get(self, "account_tier")

    @property
    @pulumi.getter(name="allowNestedItemsToBePublic")
    def allow_nested_items_to_be_public(self) -> bool:
        """
        Can nested items in the storage account opt into allowing public access?
        """
        return pulumi.get(self, "allow_nested_items_to_be_public")

    @property
    @pulumi.getter(name="azureFilesAuthentications")
    def azure_files_authentications(self) -> Sequence['outputs.GetAccountAzureFilesAuthenticationResult']:
        """
        A `azure_files_authentication` block as documented below.
        """
        return pulumi.get(self, "azure_files_authentications")

    @property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Sequence['outputs.GetAccountCustomDomainResult']:
        """
        supports the following:
        """
        return pulumi.get(self, "custom_domains")

    @property
    @pulumi.getter(name="dnsEndpointType")
    def dns_endpoint_type(self) -> str:
        """
        Which DNS endpoint type is used - either `Standard` or `AzureDnsZone`.
        """
        return pulumi.get(self, "dns_endpoint_type")

    @property
    @pulumi.getter(name="httpsTrafficOnlyEnabled")
    def https_traffic_only_enabled(self) -> bool:
        """
        Is traffic only allowed via HTTPS? See [here](https://docs.microsoft.com/azure/storage/storage-require-secure-transfer/) for more information.
        """
        return pulumi.get(self, "https_traffic_only_enabled")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def identities(self) -> Sequence['outputs.GetAccountIdentityResult']:
        """
        An `identity` block as documented below.
        """
        return pulumi.get(self, "identities")

    @property
    @pulumi.getter(name="infrastructureEncryptionEnabled")
    def infrastructure_encryption_enabled(self) -> bool:
        """
        Is infrastructure encryption enabled? See [here](https://docs.microsoft.com/azure/storage/common/infrastructure-encryption-enable/)
        for more information.
        """
        return pulumi.get(self, "infrastructure_encryption_enabled")

    @property
    @pulumi.getter(name="isHnsEnabled")
    def is_hns_enabled(self) -> bool:
        """
        Is Hierarchical Namespace enabled?
        """
        return pulumi.get(self, "is_hns_enabled")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The Azure location where the Storage Account exists
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="minTlsVersion")
    def min_tls_version(self) -> Optional[str]:
        """
        The minimum supported TLS version for this storage account.
        """
        return pulumi.get(self, "min_tls_version")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The Custom Domain Name used for the Storage Account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nfsv3Enabled")
    def nfsv3_enabled(self) -> bool:
        """
        Is NFSv3 protocol enabled?
        """
        return pulumi.get(self, "nfsv3_enabled")

    @property
    @pulumi.getter(name="primaryAccessKey")
    def primary_access_key(self) -> str:
        """
        The primary access key for the Storage Account.
        """
        return pulumi.get(self, "primary_access_key")

    @property
    @pulumi.getter(name="primaryBlobConnectionString")
    def primary_blob_connection_string(self) -> str:
        """
        The connection string associated with the primary blob location
        """
        return pulumi.get(self, "primary_blob_connection_string")

    @property
    @pulumi.getter(name="primaryBlobEndpoint")
    def primary_blob_endpoint(self) -> str:
        """
        The endpoint URL for blob storage in the primary location.
        """
        return pulumi.get(self, "primary_blob_endpoint")

    @property
    @pulumi.getter(name="primaryBlobHost")
    def primary_blob_host(self) -> str:
        """
        The hostname with port if applicable for blob storage in the primary location.
        """
        return pulumi.get(self, "primary_blob_host")

    @property
    @pulumi.getter(name="primaryBlobInternetEndpoint")
    def primary_blob_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for blob storage in the primary location.
        """
        return pulumi.get(self, "primary_blob_internet_endpoint")

    @property
    @pulumi.getter(name="primaryBlobInternetHost")
    def primary_blob_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for blob storage in the primary location.
        """
        return pulumi.get(self, "primary_blob_internet_host")

    @property
    @pulumi.getter(name="primaryBlobMicrosoftEndpoint")
    def primary_blob_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for blob storage in the primary location.
        """
        return pulumi.get(self, "primary_blob_microsoft_endpoint")

    @property
    @pulumi.getter(name="primaryBlobMicrosoftHost")
    def primary_blob_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for blob storage in the primary location.
        """
        return pulumi.get(self, "primary_blob_microsoft_host")

    @property
    @pulumi.getter(name="primaryConnectionString")
    def primary_connection_string(self) -> str:
        """
        The connection string associated with the primary location
        """
        return pulumi.get(self, "primary_connection_string")

    @property
    @pulumi.getter(name="primaryDfsEndpoint")
    def primary_dfs_endpoint(self) -> str:
        """
        The endpoint URL for DFS storage in the primary location.
        """
        return pulumi.get(self, "primary_dfs_endpoint")

    @property
    @pulumi.getter(name="primaryDfsHost")
    def primary_dfs_host(self) -> str:
        """
        The hostname with port if applicable for DFS storage in the primary location.
        """
        return pulumi.get(self, "primary_dfs_host")

    @property
    @pulumi.getter(name="primaryDfsInternetEndpoint")
    def primary_dfs_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for DFS storage in the primary location.
        """
        return pulumi.get(self, "primary_dfs_internet_endpoint")

    @property
    @pulumi.getter(name="primaryDfsInternetHost")
    def primary_dfs_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for DFS storage in the primary location.
        """
        return pulumi.get(self, "primary_dfs_internet_host")

    @property
    @pulumi.getter(name="primaryDfsMicrosoftEndpoint")
    def primary_dfs_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for DFS storage in the primary location.
        """
        return pulumi.get(self, "primary_dfs_microsoft_endpoint")

    @property
    @pulumi.getter(name="primaryDfsMicrosoftHost")
    def primary_dfs_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for DFS storage in the primary location.
        """
        return pulumi.get(self, "primary_dfs_microsoft_host")

    @property
    @pulumi.getter(name="primaryFileEndpoint")
    def primary_file_endpoint(self) -> str:
        """
        The endpoint URL for file storage in the primary location.
        """
        return pulumi.get(self, "primary_file_endpoint")

    @property
    @pulumi.getter(name="primaryFileHost")
    def primary_file_host(self) -> str:
        """
        The hostname with port if applicable for file storage in the primary location.
        """
        return pulumi.get(self, "primary_file_host")

    @property
    @pulumi.getter(name="primaryFileInternetEndpoint")
    def primary_file_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for file storage in the primary location.
        """
        return pulumi.get(self, "primary_file_internet_endpoint")

    @property
    @pulumi.getter(name="primaryFileInternetHost")
    def primary_file_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for file storage in the primary location.
        """
        return pulumi.get(self, "primary_file_internet_host")

    @property
    @pulumi.getter(name="primaryFileMicrosoftEndpoint")
    def primary_file_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for file storage in the primary location.
        """
        return pulumi.get(self, "primary_file_microsoft_endpoint")

    @property
    @pulumi.getter(name="primaryFileMicrosoftHost")
    def primary_file_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for file storage in the primary location.
        """
        return pulumi.get(self, "primary_file_microsoft_host")

    @property
    @pulumi.getter(name="primaryLocation")
    def primary_location(self) -> str:
        """
        The primary location of the Storage Account.
        """
        return pulumi.get(self, "primary_location")

    @property
    @pulumi.getter(name="primaryQueueEndpoint")
    def primary_queue_endpoint(self) -> str:
        """
        The endpoint URL for queue storage in the primary location.
        """
        return pulumi.get(self, "primary_queue_endpoint")

    @property
    @pulumi.getter(name="primaryQueueHost")
    def primary_queue_host(self) -> str:
        """
        The hostname with port if applicable for queue storage in the primary location.
        """
        return pulumi.get(self, "primary_queue_host")

    @property
    @pulumi.getter(name="primaryQueueMicrosoftEndpoint")
    def primary_queue_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for queue storage in the primary location.
        """
        return pulumi.get(self, "primary_queue_microsoft_endpoint")

    @property
    @pulumi.getter(name="primaryQueueMicrosoftHost")
    def primary_queue_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for queue storage in the primary location.
        """
        return pulumi.get(self, "primary_queue_microsoft_host")

    @property
    @pulumi.getter(name="primaryTableEndpoint")
    def primary_table_endpoint(self) -> str:
        """
        The endpoint URL for table storage in the primary location.
        """
        return pulumi.get(self, "primary_table_endpoint")

    @property
    @pulumi.getter(name="primaryTableHost")
    def primary_table_host(self) -> str:
        """
        The hostname with port if applicable for table storage in the primary location.
        """
        return pulumi.get(self, "primary_table_host")

    @property
    @pulumi.getter(name="primaryTableMicrosoftEndpoint")
    def primary_table_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for table storage in the primary location.
        """
        return pulumi.get(self, "primary_table_microsoft_endpoint")

    @property
    @pulumi.getter(name="primaryTableMicrosoftHost")
    def primary_table_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for table storage in the primary location.
        """
        return pulumi.get(self, "primary_table_microsoft_host")

    @property
    @pulumi.getter(name="primaryWebEndpoint")
    def primary_web_endpoint(self) -> str:
        """
        The endpoint URL for web storage in the primary location.
        """
        return pulumi.get(self, "primary_web_endpoint")

    @property
    @pulumi.getter(name="primaryWebHost")
    def primary_web_host(self) -> str:
        """
        The hostname with port if applicable for web storage in the primary location.
        """
        return pulumi.get(self, "primary_web_host")

    @property
    @pulumi.getter(name="primaryWebInternetEndpoint")
    def primary_web_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for web storage in the primary location.
        """
        return pulumi.get(self, "primary_web_internet_endpoint")

    @property
    @pulumi.getter(name="primaryWebInternetHost")
    def primary_web_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for web storage in the primary location.
        """
        return pulumi.get(self, "primary_web_internet_host")

    @property
    @pulumi.getter(name="primaryWebMicrosoftEndpoint")
    def primary_web_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for web storage in the primary location.
        """
        return pulumi.get(self, "primary_web_microsoft_endpoint")

    @property
    @pulumi.getter(name="primaryWebMicrosoftHost")
    def primary_web_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for web storage in the primary location.
        """
        return pulumi.get(self, "primary_web_microsoft_host")

    @property
    @pulumi.getter(name="queueEncryptionKeyType")
    def queue_encryption_key_type(self) -> str:
        """
        The encryption key type of the queue.
        """
        return pulumi.get(self, "queue_encryption_key_type")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="secondaryAccessKey")
    def secondary_access_key(self) -> str:
        """
        The secondary access key for the Storage Account.
        """
        return pulumi.get(self, "secondary_access_key")

    @property
    @pulumi.getter(name="secondaryBlobConnectionString")
    def secondary_blob_connection_string(self) -> str:
        """
        The connection string associated with the secondary blob location
        """
        return pulumi.get(self, "secondary_blob_connection_string")

    @property
    @pulumi.getter(name="secondaryBlobEndpoint")
    def secondary_blob_endpoint(self) -> str:
        """
        The endpoint URL for blob storage in the secondary location.
        """
        return pulumi.get(self, "secondary_blob_endpoint")

    @property
    @pulumi.getter(name="secondaryBlobHost")
    def secondary_blob_host(self) -> str:
        """
        The hostname with port if applicable for blob storage in the secondary location.
        """
        return pulumi.get(self, "secondary_blob_host")

    @property
    @pulumi.getter(name="secondaryBlobInternetEndpoint")
    def secondary_blob_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for blob storage in the secondary location.
        """
        return pulumi.get(self, "secondary_blob_internet_endpoint")

    @property
    @pulumi.getter(name="secondaryBlobInternetHost")
    def secondary_blob_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for blob storage in the secondary location.
        """
        return pulumi.get(self, "secondary_blob_internet_host")

    @property
    @pulumi.getter(name="secondaryBlobMicrosoftEndpoint")
    def secondary_blob_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for blob storage in the secondary location.
        """
        return pulumi.get(self, "secondary_blob_microsoft_endpoint")

    @property
    @pulumi.getter(name="secondaryBlobMicrosoftHost")
    def secondary_blob_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for blob storage in the secondary location.
        """
        return pulumi.get(self, "secondary_blob_microsoft_host")

    @property
    @pulumi.getter(name="secondaryConnectionString")
    def secondary_connection_string(self) -> str:
        """
        The connection string associated with the secondary location
        """
        return pulumi.get(self, "secondary_connection_string")

    @property
    @pulumi.getter(name="secondaryDfsEndpoint")
    def secondary_dfs_endpoint(self) -> str:
        """
        The endpoint URL for DFS storage in the secondary location.
        """
        return pulumi.get(self, "secondary_dfs_endpoint")

    @property
    @pulumi.getter(name="secondaryDfsHost")
    def secondary_dfs_host(self) -> str:
        """
        The hostname with port if applicable for DFS storage in the secondary location.
        """
        return pulumi.get(self, "secondary_dfs_host")

    @property
    @pulumi.getter(name="secondaryDfsInternetEndpoint")
    def secondary_dfs_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for DFS storage in the secondary location.
        """
        return pulumi.get(self, "secondary_dfs_internet_endpoint")

    @property
    @pulumi.getter(name="secondaryDfsInternetHost")
    def secondary_dfs_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for DFS storage in the secondary location.
        """
        return pulumi.get(self, "secondary_dfs_internet_host")

    @property
    @pulumi.getter(name="secondaryDfsMicrosoftEndpoint")
    def secondary_dfs_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for DFS storage in the secondary location.
        """
        return pulumi.get(self, "secondary_dfs_microsoft_endpoint")

    @property
    @pulumi.getter(name="secondaryDfsMicrosoftHost")
    def secondary_dfs_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for DFS storage in the secondary location.
        """
        return pulumi.get(self, "secondary_dfs_microsoft_host")

    @property
    @pulumi.getter(name="secondaryFileEndpoint")
    def secondary_file_endpoint(self) -> str:
        """
        The endpoint URL for file storage in the secondary location.
        """
        return pulumi.get(self, "secondary_file_endpoint")

    @property
    @pulumi.getter(name="secondaryFileHost")
    def secondary_file_host(self) -> str:
        """
        The hostname with port if applicable for file storage in the secondary location.
        """
        return pulumi.get(self, "secondary_file_host")

    @property
    @pulumi.getter(name="secondaryFileInternetEndpoint")
    def secondary_file_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for file storage in the secondary location.
        """
        return pulumi.get(self, "secondary_file_internet_endpoint")

    @property
    @pulumi.getter(name="secondaryFileInternetHost")
    def secondary_file_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for file storage in the secondary location.
        """
        return pulumi.get(self, "secondary_file_internet_host")

    @property
    @pulumi.getter(name="secondaryFileMicrosoftEndpoint")
    def secondary_file_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for file storage in the secondary location.
        """
        return pulumi.get(self, "secondary_file_microsoft_endpoint")

    @property
    @pulumi.getter(name="secondaryFileMicrosoftHost")
    def secondary_file_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for file storage in the secondary location.
        """
        return pulumi.get(self, "secondary_file_microsoft_host")

    @property
    @pulumi.getter(name="secondaryLocation")
    def secondary_location(self) -> str:
        """
        The secondary location of the Storage Account.
        """
        return pulumi.get(self, "secondary_location")

    @property
    @pulumi.getter(name="secondaryQueueEndpoint")
    def secondary_queue_endpoint(self) -> str:
        """
        The endpoint URL for queue storage in the secondary location.
        """
        return pulumi.get(self, "secondary_queue_endpoint")

    @property
    @pulumi.getter(name="secondaryQueueHost")
    def secondary_queue_host(self) -> str:
        """
        The hostname with port if applicable for queue storage in the secondary location.
        """
        return pulumi.get(self, "secondary_queue_host")

    @property
    @pulumi.getter(name="secondaryQueueMicrosoftEndpoint")
    def secondary_queue_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for queue storage in the secondary location.
        """
        return pulumi.get(self, "secondary_queue_microsoft_endpoint")

    @property
    @pulumi.getter(name="secondaryQueueMicrosoftHost")
    def secondary_queue_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for queue storage in the secondary location.
        """
        return pulumi.get(self, "secondary_queue_microsoft_host")

    @property
    @pulumi.getter(name="secondaryTableEndpoint")
    def secondary_table_endpoint(self) -> str:
        """
        The endpoint URL for table storage in the secondary location.
        """
        return pulumi.get(self, "secondary_table_endpoint")

    @property
    @pulumi.getter(name="secondaryTableHost")
    def secondary_table_host(self) -> str:
        """
        The hostname with port if applicable for table storage in the secondary location.
        """
        return pulumi.get(self, "secondary_table_host")

    @property
    @pulumi.getter(name="secondaryTableMicrosoftEndpoint")
    def secondary_table_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for table storage in the secondary location.
        """
        return pulumi.get(self, "secondary_table_microsoft_endpoint")

    @property
    @pulumi.getter(name="secondaryTableMicrosoftHost")
    def secondary_table_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for table storage in the secondary location.
        """
        return pulumi.get(self, "secondary_table_microsoft_host")

    @property
    @pulumi.getter(name="secondaryWebEndpoint")
    def secondary_web_endpoint(self) -> str:
        """
        The endpoint URL for web storage in the secondary location.
        """
        return pulumi.get(self, "secondary_web_endpoint")

    @property
    @pulumi.getter(name="secondaryWebHost")
    def secondary_web_host(self) -> str:
        """
        The hostname with port if applicable for web storage in the secondary location.
        """
        return pulumi.get(self, "secondary_web_host")

    @property
    @pulumi.getter(name="secondaryWebInternetEndpoint")
    def secondary_web_internet_endpoint(self) -> str:
        """
        The internet routing endpoint URL for web storage in the secondary location.
        """
        return pulumi.get(self, "secondary_web_internet_endpoint")

    @property
    @pulumi.getter(name="secondaryWebInternetHost")
    def secondary_web_internet_host(self) -> str:
        """
        The internet routing hostname with port if applicable for web storage in the secondary location.
        """
        return pulumi.get(self, "secondary_web_internet_host")

    @property
    @pulumi.getter(name="secondaryWebMicrosoftEndpoint")
    def secondary_web_microsoft_endpoint(self) -> str:
        """
        The microsoft routing endpoint URL for web storage in the secondary location.
        """
        return pulumi.get(self, "secondary_web_microsoft_endpoint")

    @property
    @pulumi.getter(name="secondaryWebMicrosoftHost")
    def secondary_web_microsoft_host(self) -> str:
        """
        The microsoft routing hostname with port if applicable for web storage in the secondary location.
        """
        return pulumi.get(self, "secondary_web_microsoft_host")

    @property
    @pulumi.getter(name="tableEncryptionKeyType")
    def table_encryption_key_type(self) -> str:
        """
        The encryption key type of the table.
        """
        return pulumi.get(self, "table_encryption_key_type")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        A mapping of tags to assigned to the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetAccountResult(GetAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountResult(
            access_tier=self.access_tier,
            account_kind=self.account_kind,
            account_replication_type=self.account_replication_type,
            account_tier=self.account_tier,
            allow_nested_items_to_be_public=self.allow_nested_items_to_be_public,
            azure_files_authentications=self.azure_files_authentications,
            custom_domains=self.custom_domains,
            dns_endpoint_type=self.dns_endpoint_type,
            https_traffic_only_enabled=self.https_traffic_only_enabled,
            id=self.id,
            identities=self.identities,
            infrastructure_encryption_enabled=self.infrastructure_encryption_enabled,
            is_hns_enabled=self.is_hns_enabled,
            location=self.location,
            min_tls_version=self.min_tls_version,
            name=self.name,
            nfsv3_enabled=self.nfsv3_enabled,
            primary_access_key=self.primary_access_key,
            primary_blob_connection_string=self.primary_blob_connection_string,
            primary_blob_endpoint=self.primary_blob_endpoint,
            primary_blob_host=self.primary_blob_host,
            primary_blob_internet_endpoint=self.primary_blob_internet_endpoint,
            primary_blob_internet_host=self.primary_blob_internet_host,
            primary_blob_microsoft_endpoint=self.primary_blob_microsoft_endpoint,
            primary_blob_microsoft_host=self.primary_blob_microsoft_host,
            primary_connection_string=self.primary_connection_string,
            primary_dfs_endpoint=self.primary_dfs_endpoint,
            primary_dfs_host=self.primary_dfs_host,
            primary_dfs_internet_endpoint=self.primary_dfs_internet_endpoint,
            primary_dfs_internet_host=self.primary_dfs_internet_host,
            primary_dfs_microsoft_endpoint=self.primary_dfs_microsoft_endpoint,
            primary_dfs_microsoft_host=self.primary_dfs_microsoft_host,
            primary_file_endpoint=self.primary_file_endpoint,
            primary_file_host=self.primary_file_host,
            primary_file_internet_endpoint=self.primary_file_internet_endpoint,
            primary_file_internet_host=self.primary_file_internet_host,
            primary_file_microsoft_endpoint=self.primary_file_microsoft_endpoint,
            primary_file_microsoft_host=self.primary_file_microsoft_host,
            primary_location=self.primary_location,
            primary_queue_endpoint=self.primary_queue_endpoint,
            primary_queue_host=self.primary_queue_host,
            primary_queue_microsoft_endpoint=self.primary_queue_microsoft_endpoint,
            primary_queue_microsoft_host=self.primary_queue_microsoft_host,
            primary_table_endpoint=self.primary_table_endpoint,
            primary_table_host=self.primary_table_host,
            primary_table_microsoft_endpoint=self.primary_table_microsoft_endpoint,
            primary_table_microsoft_host=self.primary_table_microsoft_host,
            primary_web_endpoint=self.primary_web_endpoint,
            primary_web_host=self.primary_web_host,
            primary_web_internet_endpoint=self.primary_web_internet_endpoint,
            primary_web_internet_host=self.primary_web_internet_host,
            primary_web_microsoft_endpoint=self.primary_web_microsoft_endpoint,
            primary_web_microsoft_host=self.primary_web_microsoft_host,
            queue_encryption_key_type=self.queue_encryption_key_type,
            resource_group_name=self.resource_group_name,
            secondary_access_key=self.secondary_access_key,
            secondary_blob_connection_string=self.secondary_blob_connection_string,
            secondary_blob_endpoint=self.secondary_blob_endpoint,
            secondary_blob_host=self.secondary_blob_host,
            secondary_blob_internet_endpoint=self.secondary_blob_internet_endpoint,
            secondary_blob_internet_host=self.secondary_blob_internet_host,
            secondary_blob_microsoft_endpoint=self.secondary_blob_microsoft_endpoint,
            secondary_blob_microsoft_host=self.secondary_blob_microsoft_host,
            secondary_connection_string=self.secondary_connection_string,
            secondary_dfs_endpoint=self.secondary_dfs_endpoint,
            secondary_dfs_host=self.secondary_dfs_host,
            secondary_dfs_internet_endpoint=self.secondary_dfs_internet_endpoint,
            secondary_dfs_internet_host=self.secondary_dfs_internet_host,
            secondary_dfs_microsoft_endpoint=self.secondary_dfs_microsoft_endpoint,
            secondary_dfs_microsoft_host=self.secondary_dfs_microsoft_host,
            secondary_file_endpoint=self.secondary_file_endpoint,
            secondary_file_host=self.secondary_file_host,
            secondary_file_internet_endpoint=self.secondary_file_internet_endpoint,
            secondary_file_internet_host=self.secondary_file_internet_host,
            secondary_file_microsoft_endpoint=self.secondary_file_microsoft_endpoint,
            secondary_file_microsoft_host=self.secondary_file_microsoft_host,
            secondary_location=self.secondary_location,
            secondary_queue_endpoint=self.secondary_queue_endpoint,
            secondary_queue_host=self.secondary_queue_host,
            secondary_queue_microsoft_endpoint=self.secondary_queue_microsoft_endpoint,
            secondary_queue_microsoft_host=self.secondary_queue_microsoft_host,
            secondary_table_endpoint=self.secondary_table_endpoint,
            secondary_table_host=self.secondary_table_host,
            secondary_table_microsoft_endpoint=self.secondary_table_microsoft_endpoint,
            secondary_table_microsoft_host=self.secondary_table_microsoft_host,
            secondary_web_endpoint=self.secondary_web_endpoint,
            secondary_web_host=self.secondary_web_host,
            secondary_web_internet_endpoint=self.secondary_web_internet_endpoint,
            secondary_web_internet_host=self.secondary_web_internet_host,
            secondary_web_microsoft_endpoint=self.secondary_web_microsoft_endpoint,
            secondary_web_microsoft_host=self.secondary_web_microsoft_host,
            table_encryption_key_type=self.table_encryption_key_type,
            tags=self.tags)


def get_account(min_tls_version: Optional[str] = None,
                name: Optional[str] = None,
                resource_group_name: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountResult:
    """
    Use this data source to access information about an existing Storage Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.storage.get_account(name="packerimages",
        resource_group_name="packer-storage")
    pulumi.export("storageAccountTier", example.account_tier)
    ```


    :param str min_tls_version: The minimum supported TLS version for this storage account.
    :param str name: Specifies the name of the Storage Account
    :param str resource_group_name: Specifies the name of the resource group the Storage Account is located in.
    """
    __args__ = dict()
    __args__['minTlsVersion'] = min_tls_version
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:storage/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult).value

    return AwaitableGetAccountResult(
        access_tier=pulumi.get(__ret__, 'access_tier'),
        account_kind=pulumi.get(__ret__, 'account_kind'),
        account_replication_type=pulumi.get(__ret__, 'account_replication_type'),
        account_tier=pulumi.get(__ret__, 'account_tier'),
        allow_nested_items_to_be_public=pulumi.get(__ret__, 'allow_nested_items_to_be_public'),
        azure_files_authentications=pulumi.get(__ret__, 'azure_files_authentications'),
        custom_domains=pulumi.get(__ret__, 'custom_domains'),
        dns_endpoint_type=pulumi.get(__ret__, 'dns_endpoint_type'),
        https_traffic_only_enabled=pulumi.get(__ret__, 'https_traffic_only_enabled'),
        id=pulumi.get(__ret__, 'id'),
        identities=pulumi.get(__ret__, 'identities'),
        infrastructure_encryption_enabled=pulumi.get(__ret__, 'infrastructure_encryption_enabled'),
        is_hns_enabled=pulumi.get(__ret__, 'is_hns_enabled'),
        location=pulumi.get(__ret__, 'location'),
        min_tls_version=pulumi.get(__ret__, 'min_tls_version'),
        name=pulumi.get(__ret__, 'name'),
        nfsv3_enabled=pulumi.get(__ret__, 'nfsv3_enabled'),
        primary_access_key=pulumi.get(__ret__, 'primary_access_key'),
        primary_blob_connection_string=pulumi.get(__ret__, 'primary_blob_connection_string'),
        primary_blob_endpoint=pulumi.get(__ret__, 'primary_blob_endpoint'),
        primary_blob_host=pulumi.get(__ret__, 'primary_blob_host'),
        primary_blob_internet_endpoint=pulumi.get(__ret__, 'primary_blob_internet_endpoint'),
        primary_blob_internet_host=pulumi.get(__ret__, 'primary_blob_internet_host'),
        primary_blob_microsoft_endpoint=pulumi.get(__ret__, 'primary_blob_microsoft_endpoint'),
        primary_blob_microsoft_host=pulumi.get(__ret__, 'primary_blob_microsoft_host'),
        primary_connection_string=pulumi.get(__ret__, 'primary_connection_string'),
        primary_dfs_endpoint=pulumi.get(__ret__, 'primary_dfs_endpoint'),
        primary_dfs_host=pulumi.get(__ret__, 'primary_dfs_host'),
        primary_dfs_internet_endpoint=pulumi.get(__ret__, 'primary_dfs_internet_endpoint'),
        primary_dfs_internet_host=pulumi.get(__ret__, 'primary_dfs_internet_host'),
        primary_dfs_microsoft_endpoint=pulumi.get(__ret__, 'primary_dfs_microsoft_endpoint'),
        primary_dfs_microsoft_host=pulumi.get(__ret__, 'primary_dfs_microsoft_host'),
        primary_file_endpoint=pulumi.get(__ret__, 'primary_file_endpoint'),
        primary_file_host=pulumi.get(__ret__, 'primary_file_host'),
        primary_file_internet_endpoint=pulumi.get(__ret__, 'primary_file_internet_endpoint'),
        primary_file_internet_host=pulumi.get(__ret__, 'primary_file_internet_host'),
        primary_file_microsoft_endpoint=pulumi.get(__ret__, 'primary_file_microsoft_endpoint'),
        primary_file_microsoft_host=pulumi.get(__ret__, 'primary_file_microsoft_host'),
        primary_location=pulumi.get(__ret__, 'primary_location'),
        primary_queue_endpoint=pulumi.get(__ret__, 'primary_queue_endpoint'),
        primary_queue_host=pulumi.get(__ret__, 'primary_queue_host'),
        primary_queue_microsoft_endpoint=pulumi.get(__ret__, 'primary_queue_microsoft_endpoint'),
        primary_queue_microsoft_host=pulumi.get(__ret__, 'primary_queue_microsoft_host'),
        primary_table_endpoint=pulumi.get(__ret__, 'primary_table_endpoint'),
        primary_table_host=pulumi.get(__ret__, 'primary_table_host'),
        primary_table_microsoft_endpoint=pulumi.get(__ret__, 'primary_table_microsoft_endpoint'),
        primary_table_microsoft_host=pulumi.get(__ret__, 'primary_table_microsoft_host'),
        primary_web_endpoint=pulumi.get(__ret__, 'primary_web_endpoint'),
        primary_web_host=pulumi.get(__ret__, 'primary_web_host'),
        primary_web_internet_endpoint=pulumi.get(__ret__, 'primary_web_internet_endpoint'),
        primary_web_internet_host=pulumi.get(__ret__, 'primary_web_internet_host'),
        primary_web_microsoft_endpoint=pulumi.get(__ret__, 'primary_web_microsoft_endpoint'),
        primary_web_microsoft_host=pulumi.get(__ret__, 'primary_web_microsoft_host'),
        queue_encryption_key_type=pulumi.get(__ret__, 'queue_encryption_key_type'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        secondary_access_key=pulumi.get(__ret__, 'secondary_access_key'),
        secondary_blob_connection_string=pulumi.get(__ret__, 'secondary_blob_connection_string'),
        secondary_blob_endpoint=pulumi.get(__ret__, 'secondary_blob_endpoint'),
        secondary_blob_host=pulumi.get(__ret__, 'secondary_blob_host'),
        secondary_blob_internet_endpoint=pulumi.get(__ret__, 'secondary_blob_internet_endpoint'),
        secondary_blob_internet_host=pulumi.get(__ret__, 'secondary_blob_internet_host'),
        secondary_blob_microsoft_endpoint=pulumi.get(__ret__, 'secondary_blob_microsoft_endpoint'),
        secondary_blob_microsoft_host=pulumi.get(__ret__, 'secondary_blob_microsoft_host'),
        secondary_connection_string=pulumi.get(__ret__, 'secondary_connection_string'),
        secondary_dfs_endpoint=pulumi.get(__ret__, 'secondary_dfs_endpoint'),
        secondary_dfs_host=pulumi.get(__ret__, 'secondary_dfs_host'),
        secondary_dfs_internet_endpoint=pulumi.get(__ret__, 'secondary_dfs_internet_endpoint'),
        secondary_dfs_internet_host=pulumi.get(__ret__, 'secondary_dfs_internet_host'),
        secondary_dfs_microsoft_endpoint=pulumi.get(__ret__, 'secondary_dfs_microsoft_endpoint'),
        secondary_dfs_microsoft_host=pulumi.get(__ret__, 'secondary_dfs_microsoft_host'),
        secondary_file_endpoint=pulumi.get(__ret__, 'secondary_file_endpoint'),
        secondary_file_host=pulumi.get(__ret__, 'secondary_file_host'),
        secondary_file_internet_endpoint=pulumi.get(__ret__, 'secondary_file_internet_endpoint'),
        secondary_file_internet_host=pulumi.get(__ret__, 'secondary_file_internet_host'),
        secondary_file_microsoft_endpoint=pulumi.get(__ret__, 'secondary_file_microsoft_endpoint'),
        secondary_file_microsoft_host=pulumi.get(__ret__, 'secondary_file_microsoft_host'),
        secondary_location=pulumi.get(__ret__, 'secondary_location'),
        secondary_queue_endpoint=pulumi.get(__ret__, 'secondary_queue_endpoint'),
        secondary_queue_host=pulumi.get(__ret__, 'secondary_queue_host'),
        secondary_queue_microsoft_endpoint=pulumi.get(__ret__, 'secondary_queue_microsoft_endpoint'),
        secondary_queue_microsoft_host=pulumi.get(__ret__, 'secondary_queue_microsoft_host'),
        secondary_table_endpoint=pulumi.get(__ret__, 'secondary_table_endpoint'),
        secondary_table_host=pulumi.get(__ret__, 'secondary_table_host'),
        secondary_table_microsoft_endpoint=pulumi.get(__ret__, 'secondary_table_microsoft_endpoint'),
        secondary_table_microsoft_host=pulumi.get(__ret__, 'secondary_table_microsoft_host'),
        secondary_web_endpoint=pulumi.get(__ret__, 'secondary_web_endpoint'),
        secondary_web_host=pulumi.get(__ret__, 'secondary_web_host'),
        secondary_web_internet_endpoint=pulumi.get(__ret__, 'secondary_web_internet_endpoint'),
        secondary_web_internet_host=pulumi.get(__ret__, 'secondary_web_internet_host'),
        secondary_web_microsoft_endpoint=pulumi.get(__ret__, 'secondary_web_microsoft_endpoint'),
        secondary_web_microsoft_host=pulumi.get(__ret__, 'secondary_web_microsoft_host'),
        table_encryption_key_type=pulumi.get(__ret__, 'table_encryption_key_type'),
        tags=pulumi.get(__ret__, 'tags'))
def get_account_output(min_tls_version: Optional[pulumi.Input[Optional[str]]] = None,
                       name: Optional[pulumi.Input[str]] = None,
                       resource_group_name: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountResult]:
    """
    Use this data source to access information about an existing Storage Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.storage.get_account(name="packerimages",
        resource_group_name="packer-storage")
    pulumi.export("storageAccountTier", example.account_tier)
    ```


    :param str min_tls_version: The minimum supported TLS version for this storage account.
    :param str name: Specifies the name of the Storage Account
    :param str resource_group_name: Specifies the name of the resource group the Storage Account is located in.
    """
    __args__ = dict()
    __args__['minTlsVersion'] = min_tls_version
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:storage/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult)
    return __ret__.apply(lambda __response__: GetAccountResult(
        access_tier=pulumi.get(__response__, 'access_tier'),
        account_kind=pulumi.get(__response__, 'account_kind'),
        account_replication_type=pulumi.get(__response__, 'account_replication_type'),
        account_tier=pulumi.get(__response__, 'account_tier'),
        allow_nested_items_to_be_public=pulumi.get(__response__, 'allow_nested_items_to_be_public'),
        azure_files_authentications=pulumi.get(__response__, 'azure_files_authentications'),
        custom_domains=pulumi.get(__response__, 'custom_domains'),
        dns_endpoint_type=pulumi.get(__response__, 'dns_endpoint_type'),
        https_traffic_only_enabled=pulumi.get(__response__, 'https_traffic_only_enabled'),
        id=pulumi.get(__response__, 'id'),
        identities=pulumi.get(__response__, 'identities'),
        infrastructure_encryption_enabled=pulumi.get(__response__, 'infrastructure_encryption_enabled'),
        is_hns_enabled=pulumi.get(__response__, 'is_hns_enabled'),
        location=pulumi.get(__response__, 'location'),
        min_tls_version=pulumi.get(__response__, 'min_tls_version'),
        name=pulumi.get(__response__, 'name'),
        nfsv3_enabled=pulumi.get(__response__, 'nfsv3_enabled'),
        primary_access_key=pulumi.get(__response__, 'primary_access_key'),
        primary_blob_connection_string=pulumi.get(__response__, 'primary_blob_connection_string'),
        primary_blob_endpoint=pulumi.get(__response__, 'primary_blob_endpoint'),
        primary_blob_host=pulumi.get(__response__, 'primary_blob_host'),
        primary_blob_internet_endpoint=pulumi.get(__response__, 'primary_blob_internet_endpoint'),
        primary_blob_internet_host=pulumi.get(__response__, 'primary_blob_internet_host'),
        primary_blob_microsoft_endpoint=pulumi.get(__response__, 'primary_blob_microsoft_endpoint'),
        primary_blob_microsoft_host=pulumi.get(__response__, 'primary_blob_microsoft_host'),
        primary_connection_string=pulumi.get(__response__, 'primary_connection_string'),
        primary_dfs_endpoint=pulumi.get(__response__, 'primary_dfs_endpoint'),
        primary_dfs_host=pulumi.get(__response__, 'primary_dfs_host'),
        primary_dfs_internet_endpoint=pulumi.get(__response__, 'primary_dfs_internet_endpoint'),
        primary_dfs_internet_host=pulumi.get(__response__, 'primary_dfs_internet_host'),
        primary_dfs_microsoft_endpoint=pulumi.get(__response__, 'primary_dfs_microsoft_endpoint'),
        primary_dfs_microsoft_host=pulumi.get(__response__, 'primary_dfs_microsoft_host'),
        primary_file_endpoint=pulumi.get(__response__, 'primary_file_endpoint'),
        primary_file_host=pulumi.get(__response__, 'primary_file_host'),
        primary_file_internet_endpoint=pulumi.get(__response__, 'primary_file_internet_endpoint'),
        primary_file_internet_host=pulumi.get(__response__, 'primary_file_internet_host'),
        primary_file_microsoft_endpoint=pulumi.get(__response__, 'primary_file_microsoft_endpoint'),
        primary_file_microsoft_host=pulumi.get(__response__, 'primary_file_microsoft_host'),
        primary_location=pulumi.get(__response__, 'primary_location'),
        primary_queue_endpoint=pulumi.get(__response__, 'primary_queue_endpoint'),
        primary_queue_host=pulumi.get(__response__, 'primary_queue_host'),
        primary_queue_microsoft_endpoint=pulumi.get(__response__, 'primary_queue_microsoft_endpoint'),
        primary_queue_microsoft_host=pulumi.get(__response__, 'primary_queue_microsoft_host'),
        primary_table_endpoint=pulumi.get(__response__, 'primary_table_endpoint'),
        primary_table_host=pulumi.get(__response__, 'primary_table_host'),
        primary_table_microsoft_endpoint=pulumi.get(__response__, 'primary_table_microsoft_endpoint'),
        primary_table_microsoft_host=pulumi.get(__response__, 'primary_table_microsoft_host'),
        primary_web_endpoint=pulumi.get(__response__, 'primary_web_endpoint'),
        primary_web_host=pulumi.get(__response__, 'primary_web_host'),
        primary_web_internet_endpoint=pulumi.get(__response__, 'primary_web_internet_endpoint'),
        primary_web_internet_host=pulumi.get(__response__, 'primary_web_internet_host'),
        primary_web_microsoft_endpoint=pulumi.get(__response__, 'primary_web_microsoft_endpoint'),
        primary_web_microsoft_host=pulumi.get(__response__, 'primary_web_microsoft_host'),
        queue_encryption_key_type=pulumi.get(__response__, 'queue_encryption_key_type'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        secondary_access_key=pulumi.get(__response__, 'secondary_access_key'),
        secondary_blob_connection_string=pulumi.get(__response__, 'secondary_blob_connection_string'),
        secondary_blob_endpoint=pulumi.get(__response__, 'secondary_blob_endpoint'),
        secondary_blob_host=pulumi.get(__response__, 'secondary_blob_host'),
        secondary_blob_internet_endpoint=pulumi.get(__response__, 'secondary_blob_internet_endpoint'),
        secondary_blob_internet_host=pulumi.get(__response__, 'secondary_blob_internet_host'),
        secondary_blob_microsoft_endpoint=pulumi.get(__response__, 'secondary_blob_microsoft_endpoint'),
        secondary_blob_microsoft_host=pulumi.get(__response__, 'secondary_blob_microsoft_host'),
        secondary_connection_string=pulumi.get(__response__, 'secondary_connection_string'),
        secondary_dfs_endpoint=pulumi.get(__response__, 'secondary_dfs_endpoint'),
        secondary_dfs_host=pulumi.get(__response__, 'secondary_dfs_host'),
        secondary_dfs_internet_endpoint=pulumi.get(__response__, 'secondary_dfs_internet_endpoint'),
        secondary_dfs_internet_host=pulumi.get(__response__, 'secondary_dfs_internet_host'),
        secondary_dfs_microsoft_endpoint=pulumi.get(__response__, 'secondary_dfs_microsoft_endpoint'),
        secondary_dfs_microsoft_host=pulumi.get(__response__, 'secondary_dfs_microsoft_host'),
        secondary_file_endpoint=pulumi.get(__response__, 'secondary_file_endpoint'),
        secondary_file_host=pulumi.get(__response__, 'secondary_file_host'),
        secondary_file_internet_endpoint=pulumi.get(__response__, 'secondary_file_internet_endpoint'),
        secondary_file_internet_host=pulumi.get(__response__, 'secondary_file_internet_host'),
        secondary_file_microsoft_endpoint=pulumi.get(__response__, 'secondary_file_microsoft_endpoint'),
        secondary_file_microsoft_host=pulumi.get(__response__, 'secondary_file_microsoft_host'),
        secondary_location=pulumi.get(__response__, 'secondary_location'),
        secondary_queue_endpoint=pulumi.get(__response__, 'secondary_queue_endpoint'),
        secondary_queue_host=pulumi.get(__response__, 'secondary_queue_host'),
        secondary_queue_microsoft_endpoint=pulumi.get(__response__, 'secondary_queue_microsoft_endpoint'),
        secondary_queue_microsoft_host=pulumi.get(__response__, 'secondary_queue_microsoft_host'),
        secondary_table_endpoint=pulumi.get(__response__, 'secondary_table_endpoint'),
        secondary_table_host=pulumi.get(__response__, 'secondary_table_host'),
        secondary_table_microsoft_endpoint=pulumi.get(__response__, 'secondary_table_microsoft_endpoint'),
        secondary_table_microsoft_host=pulumi.get(__response__, 'secondary_table_microsoft_host'),
        secondary_web_endpoint=pulumi.get(__response__, 'secondary_web_endpoint'),
        secondary_web_host=pulumi.get(__response__, 'secondary_web_host'),
        secondary_web_internet_endpoint=pulumi.get(__response__, 'secondary_web_internet_endpoint'),
        secondary_web_internet_host=pulumi.get(__response__, 'secondary_web_internet_host'),
        secondary_web_microsoft_endpoint=pulumi.get(__response__, 'secondary_web_microsoft_endpoint'),
        secondary_web_microsoft_host=pulumi.get(__response__, 'secondary_web_microsoft_host'),
        table_encryption_key_type=pulumi.get(__response__, 'table_encryption_key_type'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ElasticsearchLogs',
    'ElasticsearchLogsFilteringTag',
    'GetElasticsearchLogResult',
    'GetElasticsearchLogFilteringTagResult',
]

@pulumi.output_type
class ElasticsearchLogs(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "filteringTags":
            suggest = "filtering_tags"
        elif key == "sendActivityLogs":
            suggest = "send_activity_logs"
        elif key == "sendAzureadLogs":
            suggest = "send_azuread_logs"
        elif key == "sendSubscriptionLogs":
            suggest = "send_subscription_logs"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ElasticsearchLogs. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ElasticsearchLogs.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ElasticsearchLogs.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 filtering_tags: Optional[Sequence['outputs.ElasticsearchLogsFilteringTag']] = None,
                 send_activity_logs: Optional[bool] = None,
                 send_azuread_logs: Optional[bool] = None,
                 send_subscription_logs: Optional[bool] = None):
        """
        :param Sequence['ElasticsearchLogsFilteringTagArgs'] filtering_tags: A list of `filtering_tag` blocks as defined above.
        :param bool send_activity_logs: Specifies if the Azure Activity Logs should be sent to the Elasticsearch cluster. Defaults to `false`.
        :param bool send_azuread_logs: Specifies if the AzureAD Logs should be sent to the Elasticsearch cluster. Defaults to `false`.
        :param bool send_subscription_logs: Specifies if the Azure Subscription Logs should be sent to the Elasticsearch cluster. Defaults to `false`.
        """
        if filtering_tags is not None:
            pulumi.set(__self__, "filtering_tags", filtering_tags)
        if send_activity_logs is not None:
            pulumi.set(__self__, "send_activity_logs", send_activity_logs)
        if send_azuread_logs is not None:
            pulumi.set(__self__, "send_azuread_logs", send_azuread_logs)
        if send_subscription_logs is not None:
            pulumi.set(__self__, "send_subscription_logs", send_subscription_logs)

    @property
    @pulumi.getter(name="filteringTags")
    def filtering_tags(self) -> Optional[Sequence['outputs.ElasticsearchLogsFilteringTag']]:
        """
        A list of `filtering_tag` blocks as defined above.
        """
        return pulumi.get(self, "filtering_tags")

    @property
    @pulumi.getter(name="sendActivityLogs")
    def send_activity_logs(self) -> Optional[bool]:
        """
        Specifies if the Azure Activity Logs should be sent to the Elasticsearch cluster. Defaults to `false`.
        """
        return pulumi.get(self, "send_activity_logs")

    @property
    @pulumi.getter(name="sendAzureadLogs")
    def send_azuread_logs(self) -> Optional[bool]:
        """
        Specifies if the AzureAD Logs should be sent to the Elasticsearch cluster. Defaults to `false`.
        """
        return pulumi.get(self, "send_azuread_logs")

    @property
    @pulumi.getter(name="sendSubscriptionLogs")
    def send_subscription_logs(self) -> Optional[bool]:
        """
        Specifies if the Azure Subscription Logs should be sent to the Elasticsearch cluster. Defaults to `false`.
        """
        return pulumi.get(self, "send_subscription_logs")


@pulumi.output_type
class ElasticsearchLogsFilteringTag(dict):
    def __init__(__self__, *,
                 action: str,
                 name: str,
                 value: str):
        """
        :param str action: Specifies the type of action which should be taken when the Tag matches the `name` and `value`. Possible values are `Exclude` and `Include`.
        :param str name: Specifies the name (key) of the Tag which should be filtered.
        :param str value: Specifies the value of the Tag which should be filtered.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        Specifies the type of action which should be taken when the Tag matches the `name` and `value`. Possible values are `Exclude` and `Include`.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Specifies the name (key) of the Tag which should be filtered.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Specifies the value of the Tag which should be filtered.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetElasticsearchLogResult(dict):
    def __init__(__self__, *,
                 filtering_tags: Sequence['outputs.GetElasticsearchLogFilteringTagResult'],
                 send_activity_logs: bool,
                 send_azuread_logs: bool,
                 send_subscription_logs: bool):
        """
        :param Sequence['GetElasticsearchLogFilteringTagArgs'] filtering_tags: A list of `filtering_tag` blocks as defined above.
        :param bool send_activity_logs: Should the Azure Activity Logs should be sent to the Elasticsearch cluster?
        :param bool send_azuread_logs: Should the AzureAD Logs should be sent to the Elasticsearch cluster?
        :param bool send_subscription_logs: Should the Azure Subscription Logs should be sent to the Elasticsearch cluster?
        """
        pulumi.set(__self__, "filtering_tags", filtering_tags)
        pulumi.set(__self__, "send_activity_logs", send_activity_logs)
        pulumi.set(__self__, "send_azuread_logs", send_azuread_logs)
        pulumi.set(__self__, "send_subscription_logs", send_subscription_logs)

    @property
    @pulumi.getter(name="filteringTags")
    def filtering_tags(self) -> Sequence['outputs.GetElasticsearchLogFilteringTagResult']:
        """
        A list of `filtering_tag` blocks as defined above.
        """
        return pulumi.get(self, "filtering_tags")

    @property
    @pulumi.getter(name="sendActivityLogs")
    def send_activity_logs(self) -> bool:
        """
        Should the Azure Activity Logs should be sent to the Elasticsearch cluster?
        """
        return pulumi.get(self, "send_activity_logs")

    @property
    @pulumi.getter(name="sendAzureadLogs")
    def send_azuread_logs(self) -> bool:
        """
        Should the AzureAD Logs should be sent to the Elasticsearch cluster?
        """
        return pulumi.get(self, "send_azuread_logs")

    @property
    @pulumi.getter(name="sendSubscriptionLogs")
    def send_subscription_logs(self) -> bool:
        """
        Should the Azure Subscription Logs should be sent to the Elasticsearch cluster?
        """
        return pulumi.get(self, "send_subscription_logs")


@pulumi.output_type
class GetElasticsearchLogFilteringTagResult(dict):
    def __init__(__self__, *,
                 action: str,
                 name: str,
                 value: str):
        """
        :param str action: The type of action which is taken when the Tag matches the `name` and `value`.
        :param str name: The name of the Elasticsearch resource.
        :param str value: The value of the Tag which should be filtered.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        The type of action which is taken when the Tag matches the `name` and `value`.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the Elasticsearch resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value of the Tag which should be filtered.
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPublicIpPrefixResult',
    'AwaitableGetPublicIpPrefixResult',
    'get_public_ip_prefix',
    'get_public_ip_prefix_output',
]

@pulumi.output_type
class GetPublicIpPrefixResult:
    """
    A collection of values returned by getPublicIpPrefix.
    """
    def __init__(__self__, id=None, ip_prefix=None, location=None, name=None, prefix_length=None, resource_group_name=None, sku=None, sku_tier=None, tags=None, zones=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_prefix and not isinstance(ip_prefix, str):
            raise TypeError("Expected argument 'ip_prefix' to be a str")
        pulumi.set(__self__, "ip_prefix", ip_prefix)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if prefix_length and not isinstance(prefix_length, int):
            raise TypeError("Expected argument 'prefix_length' to be a int")
        pulumi.set(__self__, "prefix_length", prefix_length)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if sku and not isinstance(sku, str):
            raise TypeError("Expected argument 'sku' to be a str")
        pulumi.set(__self__, "sku", sku)
        if sku_tier and not isinstance(sku_tier, str):
            raise TypeError("Expected argument 'sku_tier' to be a str")
        pulumi.set(__self__, "sku_tier", sku_tier)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if zones and not isinstance(zones, list):
            raise TypeError("Expected argument 'zones' to be a list")
        pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipPrefix")
    def ip_prefix(self) -> str:
        """
        The Public IP address range, in CIDR notation.
        """
        return pulumi.get(self, "ip_prefix")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The supported Azure location where the resource exists.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="prefixLength")
    def prefix_length(self) -> int:
        """
        The number of bits of the prefix.
        """
        return pulumi.get(self, "prefix_length")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def sku(self) -> str:
        """
        The SKU of the Public IP Prefix.
        """
        return pulumi.get(self, "sku")

    @property
    @pulumi.getter(name="skuTier")
    def sku_tier(self) -> str:
        """
        The SKU Tier of the Public IP.
        """
        return pulumi.get(self, "sku_tier")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        A mapping of tags to assigned to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def zones(self) -> Sequence[str]:
        """
        A list of Availability Zones in which this Public IP Prefix is located.
        """
        return pulumi.get(self, "zones")


class AwaitableGetPublicIpPrefixResult(GetPublicIpPrefixResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPublicIpPrefixResult(
            id=self.id,
            ip_prefix=self.ip_prefix,
            location=self.location,
            name=self.name,
            prefix_length=self.prefix_length,
            resource_group_name=self.resource_group_name,
            sku=self.sku,
            sku_tier=self.sku_tier,
            tags=self.tags,
            zones=self.zones)


def get_public_ip_prefix(name: Optional[str] = None,
                         resource_group_name: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPublicIpPrefixResult:
    """
    Use this data source to access information about an existing Public IP Prefix.

    ## Example Usage

    ### Reference An Existing)

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_public_ip_prefix(name="name_of_public_ip",
        resource_group_name="name_of_resource_group")
    pulumi.export("publicIpPrefix", example.ip_prefix)
    ```


    :param str name: Specifies the name of the public IP prefix.
    :param str resource_group_name: Specifies the name of the resource group.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:network/getPublicIpPrefix:getPublicIpPrefix', __args__, opts=opts, typ=GetPublicIpPrefixResult).value

    return AwaitableGetPublicIpPrefixResult(
        id=pulumi.get(__ret__, 'id'),
        ip_prefix=pulumi.get(__ret__, 'ip_prefix'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        prefix_length=pulumi.get(__ret__, 'prefix_length'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        sku=pulumi.get(__ret__, 'sku'),
        sku_tier=pulumi.get(__ret__, 'sku_tier'),
        tags=pulumi.get(__ret__, 'tags'),
        zones=pulumi.get(__ret__, 'zones'))
def get_public_ip_prefix_output(name: Optional[pulumi.Input[str]] = None,
                                resource_group_name: Optional[pulumi.Input[str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPublicIpPrefixResult]:
    """
    Use this data source to access information about an existing Public IP Prefix.

    ## Example Usage

    ### Reference An Existing)

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_public_ip_prefix(name="name_of_public_ip",
        resource_group_name="name_of_resource_group")
    pulumi.export("publicIpPrefix", example.ip_prefix)
    ```


    :param str name: Specifies the name of the public IP prefix.
    :param str resource_group_name: Specifies the name of the resource group.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:network/getPublicIpPrefix:getPublicIpPrefix', __args__, opts=opts, typ=GetPublicIpPrefixResult)
    return __ret__.apply(lambda __response__: GetPublicIpPrefixResult(
        id=pulumi.get(__response__, 'id'),
        ip_prefix=pulumi.get(__response__, 'ip_prefix'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        prefix_length=pulumi.get(__response__, 'prefix_length'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        sku=pulumi.get(__response__, 'sku'),
        sku_tier=pulumi.get(__response__, 'sku_tier'),
        tags=pulumi.get(__response__, 'tags'),
        zones=pulumi.get(__response__, 'zones')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ExtensionArgs', 'Extension']

@pulumi.input_type
class ExtensionArgs:
    def __init__(__self__, *,
                 publisher: pulumi.Input[str],
                 type: pulumi.Input[str],
                 type_handler_version: pulumi.Input[str],
                 virtual_machine_id: pulumi.Input[str],
                 auto_upgrade_minor_version: Optional[pulumi.Input[bool]] = None,
                 automatic_upgrade_enabled: Optional[pulumi.Input[bool]] = None,
                 failure_suppression_enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 protected_settings: Optional[pulumi.Input[str]] = None,
                 protected_settings_from_key_vault: Optional[pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs']] = None,
                 provision_after_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 settings: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Extension resource.
        :param pulumi.Input[str] publisher: The publisher of the extension, available publishers can be found by using the Azure CLI. Changing this forces a new resource to be created.
        :param pulumi.Input[str] type: The type of extension, available types for a publisher can be found using the Azure CLI.
               
               > **Note:** The `Publisher` and `Type` of Virtual Machine Extensions can be found using the Azure CLI, via:
               
               ```shell
               az vm extension image list --location westus -o table
               ```
        :param pulumi.Input[str] type_handler_version: Specifies the version of the extension to use, available versions can be found using the Azure CLI.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created
        :param pulumi.Input[bool] auto_upgrade_minor_version: Specifies if the platform deploys the latest minor version update to the `type_handler_version` specified.
        :param pulumi.Input[bool] automatic_upgrade_enabled: Should the Extension be automatically updated whenever the Publisher releases a new version of this VM Extension?
        :param pulumi.Input[bool] failure_suppression_enabled: Should failures from the extension be suppressed? Possible values are `true` or `false`. Defaults to `false`.
               
               > **NOTE:** Operational failures such as not connecting to the VM will not be suppressed regardless of the `failure_suppression_enabled` value.
        :param pulumi.Input[str] name: The name of the virtual machine extension peering. Changing this forces a new resource to be created.
        :param pulumi.Input[str] protected_settings: The protected_settings passed to the extension, like settings, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `protected_settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs'] protected_settings_from_key_vault: A `protected_settings_from_key_vault` block as defined below.
               
               > **Note:** `protected_settings_from_key_vault` cannot be used with `protected_settings`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] provision_after_extensions: Specifies the collection of extension names after which this extension needs to be provisioned.
        :param pulumi.Input[str] settings: The settings passed to the extension, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "publisher", publisher)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "type_handler_version", type_handler_version)
        pulumi.set(__self__, "virtual_machine_id", virtual_machine_id)
        if auto_upgrade_minor_version is not None:
            pulumi.set(__self__, "auto_upgrade_minor_version", auto_upgrade_minor_version)
        if automatic_upgrade_enabled is not None:
            pulumi.set(__self__, "automatic_upgrade_enabled", automatic_upgrade_enabled)
        if failure_suppression_enabled is not None:
            pulumi.set(__self__, "failure_suppression_enabled", failure_suppression_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protected_settings is not None:
            pulumi.set(__self__, "protected_settings", protected_settings)
        if protected_settings_from_key_vault is not None:
            pulumi.set(__self__, "protected_settings_from_key_vault", protected_settings_from_key_vault)
        if provision_after_extensions is not None:
            pulumi.set(__self__, "provision_after_extensions", provision_after_extensions)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def publisher(self) -> pulumi.Input[str]:
        """
        The publisher of the extension, available publishers can be found by using the Azure CLI. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "publisher")

    @publisher.setter
    def publisher(self, value: pulumi.Input[str]):
        pulumi.set(self, "publisher", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of extension, available types for a publisher can be found using the Azure CLI.

        > **Note:** The `Publisher` and `Type` of Virtual Machine Extensions can be found using the Azure CLI, via:

        ```shell
        az vm extension image list --location westus -o table
        ```
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="typeHandlerVersion")
    def type_handler_version(self) -> pulumi.Input[str]:
        """
        Specifies the version of the extension to use, available versions can be found using the Azure CLI.
        """
        return pulumi.get(self, "type_handler_version")

    @type_handler_version.setter
    def type_handler_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "type_handler_version", value)

    @property
    @pulumi.getter(name="virtualMachineId")
    def virtual_machine_id(self) -> pulumi.Input[str]:
        """
        The ID of the Virtual Machine. Changing this forces a new resource to be created
        """
        return pulumi.get(self, "virtual_machine_id")

    @virtual_machine_id.setter
    def virtual_machine_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "virtual_machine_id", value)

    @property
    @pulumi.getter(name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies if the platform deploys the latest minor version update to the `type_handler_version` specified.
        """
        return pulumi.get(self, "auto_upgrade_minor_version")

    @auto_upgrade_minor_version.setter
    def auto_upgrade_minor_version(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_upgrade_minor_version", value)

    @property
    @pulumi.getter(name="automaticUpgradeEnabled")
    def automatic_upgrade_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should the Extension be automatically updated whenever the Publisher releases a new version of this VM Extension?
        """
        return pulumi.get(self, "automatic_upgrade_enabled")

    @automatic_upgrade_enabled.setter
    def automatic_upgrade_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "automatic_upgrade_enabled", value)

    @property
    @pulumi.getter(name="failureSuppressionEnabled")
    def failure_suppression_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should failures from the extension be suppressed? Possible values are `true` or `false`. Defaults to `false`.

        > **NOTE:** Operational failures such as not connecting to the VM will not be suppressed regardless of the `failure_suppression_enabled` value.
        """
        return pulumi.get(self, "failure_suppression_enabled")

    @failure_suppression_enabled.setter
    def failure_suppression_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "failure_suppression_enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the virtual machine extension peering. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="protectedSettings")
    def protected_settings(self) -> Optional[pulumi.Input[str]]:
        """
        The protected_settings passed to the extension, like settings, these are specified as a JSON object in a string.

        > **Please Note:** Certain VM Extensions require that the keys in the `protected_settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        """
        return pulumi.get(self, "protected_settings")

    @protected_settings.setter
    def protected_settings(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protected_settings", value)

    @property
    @pulumi.getter(name="protectedSettingsFromKeyVault")
    def protected_settings_from_key_vault(self) -> Optional[pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs']]:
        """
        A `protected_settings_from_key_vault` block as defined below.

        > **Note:** `protected_settings_from_key_vault` cannot be used with `protected_settings`
        """
        return pulumi.get(self, "protected_settings_from_key_vault")

    @protected_settings_from_key_vault.setter
    def protected_settings_from_key_vault(self, value: Optional[pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs']]):
        pulumi.set(self, "protected_settings_from_key_vault", value)

    @property
    @pulumi.getter(name="provisionAfterExtensions")
    def provision_after_extensions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the collection of extension names after which this extension needs to be provisioned.
        """
        return pulumi.get(self, "provision_after_extensions")

    @provision_after_extensions.setter
    def provision_after_extensions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "provision_after_extensions", value)

    @property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input[str]]:
        """
        The settings passed to the extension, these are specified as a JSON object in a string.

        > **Please Note:** Certain VM Extensions require that the keys in the `settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "settings", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ExtensionState:
    def __init__(__self__, *,
                 auto_upgrade_minor_version: Optional[pulumi.Input[bool]] = None,
                 automatic_upgrade_enabled: Optional[pulumi.Input[bool]] = None,
                 failure_suppression_enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 protected_settings: Optional[pulumi.Input[str]] = None,
                 protected_settings_from_key_vault: Optional[pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs']] = None,
                 provision_after_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 publisher: Optional[pulumi.Input[str]] = None,
                 settings: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 type_handler_version: Optional[pulumi.Input[str]] = None,
                 virtual_machine_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Extension resources.
        :param pulumi.Input[bool] auto_upgrade_minor_version: Specifies if the platform deploys the latest minor version update to the `type_handler_version` specified.
        :param pulumi.Input[bool] automatic_upgrade_enabled: Should the Extension be automatically updated whenever the Publisher releases a new version of this VM Extension?
        :param pulumi.Input[bool] failure_suppression_enabled: Should failures from the extension be suppressed? Possible values are `true` or `false`. Defaults to `false`.
               
               > **NOTE:** Operational failures such as not connecting to the VM will not be suppressed regardless of the `failure_suppression_enabled` value.
        :param pulumi.Input[str] name: The name of the virtual machine extension peering. Changing this forces a new resource to be created.
        :param pulumi.Input[str] protected_settings: The protected_settings passed to the extension, like settings, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `protected_settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs'] protected_settings_from_key_vault: A `protected_settings_from_key_vault` block as defined below.
               
               > **Note:** `protected_settings_from_key_vault` cannot be used with `protected_settings`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] provision_after_extensions: Specifies the collection of extension names after which this extension needs to be provisioned.
        :param pulumi.Input[str] publisher: The publisher of the extension, available publishers can be found by using the Azure CLI. Changing this forces a new resource to be created.
        :param pulumi.Input[str] settings: The settings passed to the extension, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] type: The type of extension, available types for a publisher can be found using the Azure CLI.
               
               > **Note:** The `Publisher` and `Type` of Virtual Machine Extensions can be found using the Azure CLI, via:
               
               ```shell
               az vm extension image list --location westus -o table
               ```
        :param pulumi.Input[str] type_handler_version: Specifies the version of the extension to use, available versions can be found using the Azure CLI.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created
        """
        if auto_upgrade_minor_version is not None:
            pulumi.set(__self__, "auto_upgrade_minor_version", auto_upgrade_minor_version)
        if automatic_upgrade_enabled is not None:
            pulumi.set(__self__, "automatic_upgrade_enabled", automatic_upgrade_enabled)
        if failure_suppression_enabled is not None:
            pulumi.set(__self__, "failure_suppression_enabled", failure_suppression_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protected_settings is not None:
            pulumi.set(__self__, "protected_settings", protected_settings)
        if protected_settings_from_key_vault is not None:
            pulumi.set(__self__, "protected_settings_from_key_vault", protected_settings_from_key_vault)
        if provision_after_extensions is not None:
            pulumi.set(__self__, "provision_after_extensions", provision_after_extensions)
        if publisher is not None:
            pulumi.set(__self__, "publisher", publisher)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if type_handler_version is not None:
            pulumi.set(__self__, "type_handler_version", type_handler_version)
        if virtual_machine_id is not None:
            pulumi.set(__self__, "virtual_machine_id", virtual_machine_id)

    @property
    @pulumi.getter(name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies if the platform deploys the latest minor version update to the `type_handler_version` specified.
        """
        return pulumi.get(self, "auto_upgrade_minor_version")

    @auto_upgrade_minor_version.setter
    def auto_upgrade_minor_version(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_upgrade_minor_version", value)

    @property
    @pulumi.getter(name="automaticUpgradeEnabled")
    def automatic_upgrade_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should the Extension be automatically updated whenever the Publisher releases a new version of this VM Extension?
        """
        return pulumi.get(self, "automatic_upgrade_enabled")

    @automatic_upgrade_enabled.setter
    def automatic_upgrade_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "automatic_upgrade_enabled", value)

    @property
    @pulumi.getter(name="failureSuppressionEnabled")
    def failure_suppression_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Should failures from the extension be suppressed? Possible values are `true` or `false`. Defaults to `false`.

        > **NOTE:** Operational failures such as not connecting to the VM will not be suppressed regardless of the `failure_suppression_enabled` value.
        """
        return pulumi.get(self, "failure_suppression_enabled")

    @failure_suppression_enabled.setter
    def failure_suppression_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "failure_suppression_enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the virtual machine extension peering. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="protectedSettings")
    def protected_settings(self) -> Optional[pulumi.Input[str]]:
        """
        The protected_settings passed to the extension, like settings, these are specified as a JSON object in a string.

        > **Please Note:** Certain VM Extensions require that the keys in the `protected_settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        """
        return pulumi.get(self, "protected_settings")

    @protected_settings.setter
    def protected_settings(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protected_settings", value)

    @property
    @pulumi.getter(name="protectedSettingsFromKeyVault")
    def protected_settings_from_key_vault(self) -> Optional[pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs']]:
        """
        A `protected_settings_from_key_vault` block as defined below.

        > **Note:** `protected_settings_from_key_vault` cannot be used with `protected_settings`
        """
        return pulumi.get(self, "protected_settings_from_key_vault")

    @protected_settings_from_key_vault.setter
    def protected_settings_from_key_vault(self, value: Optional[pulumi.Input['ExtensionProtectedSettingsFromKeyVaultArgs']]):
        pulumi.set(self, "protected_settings_from_key_vault", value)

    @property
    @pulumi.getter(name="provisionAfterExtensions")
    def provision_after_extensions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies the collection of extension names after which this extension needs to be provisioned.
        """
        return pulumi.get(self, "provision_after_extensions")

    @provision_after_extensions.setter
    def provision_after_extensions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "provision_after_extensions", value)

    @property
    @pulumi.getter
    def publisher(self) -> Optional[pulumi.Input[str]]:
        """
        The publisher of the extension, available publishers can be found by using the Azure CLI. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "publisher")

    @publisher.setter
    def publisher(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "publisher", value)

    @property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input[str]]:
        """
        The settings passed to the extension, these are specified as a JSON object in a string.

        > **Please Note:** Certain VM Extensions require that the keys in the `settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "settings", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of extension, available types for a publisher can be found using the Azure CLI.

        > **Note:** The `Publisher` and `Type` of Virtual Machine Extensions can be found using the Azure CLI, via:

        ```shell
        az vm extension image list --location westus -o table
        ```
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="typeHandlerVersion")
    def type_handler_version(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the version of the extension to use, available versions can be found using the Azure CLI.
        """
        return pulumi.get(self, "type_handler_version")

    @type_handler_version.setter
    def type_handler_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type_handler_version", value)

    @property
    @pulumi.getter(name="virtualMachineId")
    def virtual_machine_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Virtual Machine. Changing this forces a new resource to be created
        """
        return pulumi.get(self, "virtual_machine_id")

    @virtual_machine_id.setter
    def virtual_machine_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_machine_id", value)


class Extension(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_upgrade_minor_version: Optional[pulumi.Input[bool]] = None,
                 automatic_upgrade_enabled: Optional[pulumi.Input[bool]] = None,
                 failure_suppression_enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 protected_settings: Optional[pulumi.Input[str]] = None,
                 protected_settings_from_key_vault: Optional[pulumi.Input[Union['ExtensionProtectedSettingsFromKeyVaultArgs', 'ExtensionProtectedSettingsFromKeyVaultArgsDict']]] = None,
                 provision_after_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 publisher: Optional[pulumi.Input[str]] = None,
                 settings: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 type_handler_version: Optional[pulumi.Input[str]] = None,
                 virtual_machine_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Virtual Machine Extension to provide post deployment configuration
        and run automated tasks.

        > **NOTE:** Custom Script Extensions for Linux & Windows require that the `commandToExecute` returns a `0` exit code to be classified as successfully deployed. You can achieve this by appending `exit 0` to the end of your `commandToExecute`.

        > **NOTE:** Custom Script Extensions require that the Azure Virtual Machine Guest Agent is running on the Virtual Machine.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_std as std

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="acctvn",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="acctsub",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        example_network_interface = azure.network.NetworkInterface("example",
            name="acctni",
            location=example.location,
            resource_group_name=example.name,
            ip_configurations=[{
                "name": "testconfiguration1",
                "subnet_id": example_subnet.id,
                "private_ip_address_allocation": "Dynamic",
            }])
        example_linux_virtual_machine = azure.compute.LinuxVirtualMachine("example",
            name="example-machine",
            resource_group_name=example.name,
            location=example.location,
            size="Standard_F2",
            admin_username="adminuser",
            network_interface_ids=[example_network_interface.id],
            admin_ssh_keys=[{
                "username": "adminuser",
                "public_key": std.file(input="~/.ssh/id_rsa.pub").result,
            }],
            os_disk={
                "caching": "ReadWrite",
                "storage_account_type": "Standard_LRS",
            },
            source_image_reference={
                "publisher": "Canonical",
                "offer": "0001-com-ubuntu-server-jammy",
                "sku": "22_04-lts",
                "version": "latest",
            })
        example_extension = azure.compute.Extension("example",
            name="hostname",
            virtual_machine_id=example_linux_virtual_machine.id,
            publisher="Microsoft.Azure.Extensions",
            type="CustomScript",
            type_handler_version="2.0",
            settings=\"\"\" {
          "commandToExecute": "hostname && uptime"
         }
        \"\"\",
            tags={
                "environment": "Production",
            })
        ```

        ## Import

        Virtual Machine Extensions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:compute/extension:Extension example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Compute/virtualMachines/myVM/extensions/extensionName
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_upgrade_minor_version: Specifies if the platform deploys the latest minor version update to the `type_handler_version` specified.
        :param pulumi.Input[bool] automatic_upgrade_enabled: Should the Extension be automatically updated whenever the Publisher releases a new version of this VM Extension?
        :param pulumi.Input[bool] failure_suppression_enabled: Should failures from the extension be suppressed? Possible values are `true` or `false`. Defaults to `false`.
               
               > **NOTE:** Operational failures such as not connecting to the VM will not be suppressed regardless of the `failure_suppression_enabled` value.
        :param pulumi.Input[str] name: The name of the virtual machine extension peering. Changing this forces a new resource to be created.
        :param pulumi.Input[str] protected_settings: The protected_settings passed to the extension, like settings, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `protected_settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input[Union['ExtensionProtectedSettingsFromKeyVaultArgs', 'ExtensionProtectedSettingsFromKeyVaultArgsDict']] protected_settings_from_key_vault: A `protected_settings_from_key_vault` block as defined below.
               
               > **Note:** `protected_settings_from_key_vault` cannot be used with `protected_settings`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] provision_after_extensions: Specifies the collection of extension names after which this extension needs to be provisioned.
        :param pulumi.Input[str] publisher: The publisher of the extension, available publishers can be found by using the Azure CLI. Changing this forces a new resource to be created.
        :param pulumi.Input[str] settings: The settings passed to the extension, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] type: The type of extension, available types for a publisher can be found using the Azure CLI.
               
               > **Note:** The `Publisher` and `Type` of Virtual Machine Extensions can be found using the Azure CLI, via:
               
               ```shell
               az vm extension image list --location westus -o table
               ```
        :param pulumi.Input[str] type_handler_version: Specifies the version of the extension to use, available versions can be found using the Azure CLI.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ExtensionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Virtual Machine Extension to provide post deployment configuration
        and run automated tasks.

        > **NOTE:** Custom Script Extensions for Linux & Windows require that the `commandToExecute` returns a `0` exit code to be classified as successfully deployed. You can achieve this by appending `exit 0` to the end of your `commandToExecute`.

        > **NOTE:** Custom Script Extensions require that the Azure Virtual Machine Guest Agent is running on the Virtual Machine.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_std as std

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="acctvn",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="acctsub",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        example_network_interface = azure.network.NetworkInterface("example",
            name="acctni",
            location=example.location,
            resource_group_name=example.name,
            ip_configurations=[{
                "name": "testconfiguration1",
                "subnet_id": example_subnet.id,
                "private_ip_address_allocation": "Dynamic",
            }])
        example_linux_virtual_machine = azure.compute.LinuxVirtualMachine("example",
            name="example-machine",
            resource_group_name=example.name,
            location=example.location,
            size="Standard_F2",
            admin_username="adminuser",
            network_interface_ids=[example_network_interface.id],
            admin_ssh_keys=[{
                "username": "adminuser",
                "public_key": std.file(input="~/.ssh/id_rsa.pub").result,
            }],
            os_disk={
                "caching": "ReadWrite",
                "storage_account_type": "Standard_LRS",
            },
            source_image_reference={
                "publisher": "Canonical",
                "offer": "0001-com-ubuntu-server-jammy",
                "sku": "22_04-lts",
                "version": "latest",
            })
        example_extension = azure.compute.Extension("example",
            name="hostname",
            virtual_machine_id=example_linux_virtual_machine.id,
            publisher="Microsoft.Azure.Extensions",
            type="CustomScript",
            type_handler_version="2.0",
            settings=\"\"\" {
          "commandToExecute": "hostname && uptime"
         }
        \"\"\",
            tags={
                "environment": "Production",
            })
        ```

        ## Import

        Virtual Machine Extensions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:compute/extension:Extension example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Compute/virtualMachines/myVM/extensions/extensionName
        ```

        :param str resource_name: The name of the resource.
        :param ExtensionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ExtensionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_upgrade_minor_version: Optional[pulumi.Input[bool]] = None,
                 automatic_upgrade_enabled: Optional[pulumi.Input[bool]] = None,
                 failure_suppression_enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 protected_settings: Optional[pulumi.Input[str]] = None,
                 protected_settings_from_key_vault: Optional[pulumi.Input[Union['ExtensionProtectedSettingsFromKeyVaultArgs', 'ExtensionProtectedSettingsFromKeyVaultArgsDict']]] = None,
                 provision_after_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 publisher: Optional[pulumi.Input[str]] = None,
                 settings: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 type_handler_version: Optional[pulumi.Input[str]] = None,
                 virtual_machine_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ExtensionArgs.__new__(ExtensionArgs)

            __props__.__dict__["auto_upgrade_minor_version"] = auto_upgrade_minor_version
            __props__.__dict__["automatic_upgrade_enabled"] = automatic_upgrade_enabled
            __props__.__dict__["failure_suppression_enabled"] = failure_suppression_enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["protected_settings"] = None if protected_settings is None else pulumi.Output.secret(protected_settings)
            __props__.__dict__["protected_settings_from_key_vault"] = protected_settings_from_key_vault
            __props__.__dict__["provision_after_extensions"] = provision_after_extensions
            if publisher is None and not opts.urn:
                raise TypeError("Missing required property 'publisher'")
            __props__.__dict__["publisher"] = publisher
            __props__.__dict__["settings"] = settings
            __props__.__dict__["tags"] = tags
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if type_handler_version is None and not opts.urn:
                raise TypeError("Missing required property 'type_handler_version'")
            __props__.__dict__["type_handler_version"] = type_handler_version
            if virtual_machine_id is None and not opts.urn:
                raise TypeError("Missing required property 'virtual_machine_id'")
            __props__.__dict__["virtual_machine_id"] = virtual_machine_id
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["protectedSettings"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Extension, __self__).__init__(
            'azure:compute/extension:Extension',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_upgrade_minor_version: Optional[pulumi.Input[bool]] = None,
            automatic_upgrade_enabled: Optional[pulumi.Input[bool]] = None,
            failure_suppression_enabled: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            protected_settings: Optional[pulumi.Input[str]] = None,
            protected_settings_from_key_vault: Optional[pulumi.Input[Union['ExtensionProtectedSettingsFromKeyVaultArgs', 'ExtensionProtectedSettingsFromKeyVaultArgsDict']]] = None,
            provision_after_extensions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            publisher: Optional[pulumi.Input[str]] = None,
            settings: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            type: Optional[pulumi.Input[str]] = None,
            type_handler_version: Optional[pulumi.Input[str]] = None,
            virtual_machine_id: Optional[pulumi.Input[str]] = None) -> 'Extension':
        """
        Get an existing Extension resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_upgrade_minor_version: Specifies if the platform deploys the latest minor version update to the `type_handler_version` specified.
        :param pulumi.Input[bool] automatic_upgrade_enabled: Should the Extension be automatically updated whenever the Publisher releases a new version of this VM Extension?
        :param pulumi.Input[bool] failure_suppression_enabled: Should failures from the extension be suppressed? Possible values are `true` or `false`. Defaults to `false`.
               
               > **NOTE:** Operational failures such as not connecting to the VM will not be suppressed regardless of the `failure_suppression_enabled` value.
        :param pulumi.Input[str] name: The name of the virtual machine extension peering. Changing this forces a new resource to be created.
        :param pulumi.Input[str] protected_settings: The protected_settings passed to the extension, like settings, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `protected_settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input[Union['ExtensionProtectedSettingsFromKeyVaultArgs', 'ExtensionProtectedSettingsFromKeyVaultArgsDict']] protected_settings_from_key_vault: A `protected_settings_from_key_vault` block as defined below.
               
               > **Note:** `protected_settings_from_key_vault` cannot be used with `protected_settings`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] provision_after_extensions: Specifies the collection of extension names after which this extension needs to be provisioned.
        :param pulumi.Input[str] publisher: The publisher of the extension, available publishers can be found by using the Azure CLI. Changing this forces a new resource to be created.
        :param pulumi.Input[str] settings: The settings passed to the extension, these are specified as a JSON object in a string.
               
               > **Please Note:** Certain VM Extensions require that the keys in the `settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] type: The type of extension, available types for a publisher can be found using the Azure CLI.
               
               > **Note:** The `Publisher` and `Type` of Virtual Machine Extensions can be found using the Azure CLI, via:
               
               ```shell
               az vm extension image list --location westus -o table
               ```
        :param pulumi.Input[str] type_handler_version: Specifies the version of the extension to use, available versions can be found using the Azure CLI.
        :param pulumi.Input[str] virtual_machine_id: The ID of the Virtual Machine. Changing this forces a new resource to be created
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ExtensionState.__new__(_ExtensionState)

        __props__.__dict__["auto_upgrade_minor_version"] = auto_upgrade_minor_version
        __props__.__dict__["automatic_upgrade_enabled"] = automatic_upgrade_enabled
        __props__.__dict__["failure_suppression_enabled"] = failure_suppression_enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["protected_settings"] = protected_settings
        __props__.__dict__["protected_settings_from_key_vault"] = protected_settings_from_key_vault
        __props__.__dict__["provision_after_extensions"] = provision_after_extensions
        __props__.__dict__["publisher"] = publisher
        __props__.__dict__["settings"] = settings
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["type_handler_version"] = type_handler_version
        __props__.__dict__["virtual_machine_id"] = virtual_machine_id
        return Extension(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoUpgradeMinorVersion")
    def auto_upgrade_minor_version(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies if the platform deploys the latest minor version update to the `type_handler_version` specified.
        """
        return pulumi.get(self, "auto_upgrade_minor_version")

    @property
    @pulumi.getter(name="automaticUpgradeEnabled")
    def automatic_upgrade_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Should the Extension be automatically updated whenever the Publisher releases a new version of this VM Extension?
        """
        return pulumi.get(self, "automatic_upgrade_enabled")

    @property
    @pulumi.getter(name="failureSuppressionEnabled")
    def failure_suppression_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Should failures from the extension be suppressed? Possible values are `true` or `false`. Defaults to `false`.

        > **NOTE:** Operational failures such as not connecting to the VM will not be suppressed regardless of the `failure_suppression_enabled` value.
        """
        return pulumi.get(self, "failure_suppression_enabled")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the virtual machine extension peering. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="protectedSettings")
    def protected_settings(self) -> pulumi.Output[Optional[str]]:
        """
        The protected_settings passed to the extension, like settings, these are specified as a JSON object in a string.

        > **Please Note:** Certain VM Extensions require that the keys in the `protected_settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        """
        return pulumi.get(self, "protected_settings")

    @property
    @pulumi.getter(name="protectedSettingsFromKeyVault")
    def protected_settings_from_key_vault(self) -> pulumi.Output[Optional['outputs.ExtensionProtectedSettingsFromKeyVault']]:
        """
        A `protected_settings_from_key_vault` block as defined below.

        > **Note:** `protected_settings_from_key_vault` cannot be used with `protected_settings`
        """
        return pulumi.get(self, "protected_settings_from_key_vault")

    @property
    @pulumi.getter(name="provisionAfterExtensions")
    def provision_after_extensions(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Specifies the collection of extension names after which this extension needs to be provisioned.
        """
        return pulumi.get(self, "provision_after_extensions")

    @property
    @pulumi.getter
    def publisher(self) -> pulumi.Output[str]:
        """
        The publisher of the extension, available publishers can be found by using the Azure CLI. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "publisher")

    @property
    @pulumi.getter
    def settings(self) -> pulumi.Output[Optional[str]]:
        """
        The settings passed to the extension, these are specified as a JSON object in a string.

        > **Please Note:** Certain VM Extensions require that the keys in the `settings` block are case sensitive. If you're seeing unhelpful errors, please ensure the keys are consistent with how Azure is expecting them (for instance, for the `JsonADDomainExtension` extension, the keys are expected to be in `TitleCase`.)
        """
        return pulumi.get(self, "settings")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The type of extension, available types for a publisher can be found using the Azure CLI.

        > **Note:** The `Publisher` and `Type` of Virtual Machine Extensions can be found using the Azure CLI, via:

        ```shell
        az vm extension image list --location westus -o table
        ```
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="typeHandlerVersion")
    def type_handler_version(self) -> pulumi.Output[str]:
        """
        Specifies the version of the extension to use, available versions can be found using the Azure CLI.
        """
        return pulumi.get(self, "type_handler_version")

    @property
    @pulumi.getter(name="virtualMachineId")
    def virtual_machine_id(self) -> pulumi.Output[str]:
        """
        The ID of the Virtual Machine. Changing this forces a new resource to be created
        """
        return pulumi.get(self, "virtual_machine_id")

